/**
 * 
 * 选择聊天室 列表
 */
import React, { Component } from 'react'
import { Card, Table, Divider, Button, Modal, Drawer } from 'antd'
import styles from './SelectChatRoom.less'
// 引入接口
import { getRtcRoomPageList, getRtcCategoryPageList } from './api'
// 引入模块公用组件
import ChatRoomsFilters from './ChatRoomsFilters'
// 引入公用函数
import { getDate, showSuccess, showError, getChatRoomTypeStr } from '@/utils/base'
// 引入模块公用函数
import { getChatRoomStatusStr } from './common'

// table 列组件
const Column = Table.Column

// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}

// 列表组件
class SelectChatRoom extends Component {
  constructor(props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 处理状态
      handleStatus: undefined,
      // 分页
      pagination: {
        current: 1
      },
      selectedRows: [],
      selectedRowKeys: [],
      choosenStore: [],
      businessType: 0
    }
  }
  componentDidMount() {
    this.getList()
    this.getRtcCategoryPageList()
  }

  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const {
        handleStatus, startTime, endTime, pagination, itemName, categoryId, roomType,
        filterUserInfo, roomTitle, businessType
      } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20,
        businessType: businessType
      }
      // 名称
      if (itemName) {
        _params.roomName = itemName
      }
      // 标题
      if (roomTitle) {
        _params.roomTitle = roomTitle
      }
      // 用户
      if (filterUserInfo && filterUserInfo.userId) {
        _params.userId = filterUserInfo.userId
      }
      // 房间类型
      if ((roomType && roomType !== 'all') || roomType === 0) {
        _params.roomType = roomType
      }
      // 类目
      if (categoryId) {
        _params.categoryId = categoryId
      }
      // 配置状态
      if (handleStatus && handleStatus !== 'all') {
        _params.status = handleStatus
      }
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })

      const { data, code } = await getRtcRoomPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        list && list.map((item) => {
          item.statusStr = getChatRoomStatusStr(item.status)
          item.roomCreateTimeStr = item.roomCreateTime ? getDate(+item.roomCreateTime, 'yyyy.MM.dd') : '-'
          item.roomTypeStr = getChatRoomTypeStr(item.roomType)
        })
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  getRtcCategoryPageList = async () => {
    try {
      const { code, data } = await getRtcCategoryPageList({ pageNum: 1, pageSize: 200, status: 1 })
      if (code === 'OK' && data) {
        this.setState({
          categories: data.list
        })
      }
    } catch (e) {
      console.log(e)
    }
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 选择
  onSelect = (selectedRowKeys, selectedRows) => {
    const { choosenStore = [] } = this.state
    this.setState({ selectedRowKeys, choosenStore: choosenStore.concat(selectedRows) })
  }

  onOk = () => {
    const { choosenStore, selectedRowKeys } = this.state
    const { onOk } = this.props
    const _choosen = selectedRowKeys.map(item => choosenStore.find(subItem => item === subItem.roomId))
    onOk && onOk(_choosen)
  }

  render() {
    const { type, onCancel } = this.props
    const {
      loading, list, itemName, handleStatus, pagination, filterUserInfo, roomTitle,
      startTime, endTime, uploading, selectedRowKeys, categories, categoryId, roomType, businessType
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total

    const rowSelection = {
      selectedRowKeys,
      type: type || 'radio',
      onChange: this.onSelect
    }
    return (
      <Drawer
        title='聊天室列表'
        width={1200}
        visible
        onClose={onCancel}
      >
        <div className={styles['content-wrap']}>
          <ChatRoomsFilters
            loading={loading}
            onChange={this.onChange}
            itemName={itemName}
            handleStatus={handleStatus}
            categories={categories}
            categoryId={categoryId}
            roomTitle={roomTitle}
            roomType={roomType}
            filterUserInfo={filterUserInfo}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
            businessType={businessType}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='roomId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
            rowSelection={rowSelection}
          >
            <Column
              title='语聊室名称'
              key='roomName'
              dataIndex='roomName'
            />
            <Column
              title='语聊室编号'
              key='roomNo'
              dataIndex='roomNo'
            />
            <Column
              title='语聊室类目'
              key='categoryName'
              dataIndex='categoryName'
            />
            <Column
              title='语聊类型'
              key='roomTypeStr'
              dataIndex='roomTypeStr'
            />
            <Column
              title='状态'
              key='statusStr'
              dataIndex='statusStr'
              render={(text, { statusStr }) => (
                <div>{statusStr}</div>
              )}
            />
            <Column
              title='创建者'
              key='userName'
              dataIndex='userName'
              render={(text, { userName }) => (
                <div>
                  {userName}
                </div>
              )}
            />
            <Column
              title='创建时间'
              key='roomCreateTimeStr'
              dataIndex='roomCreateTimeStr'
              render={(text, { roomCreateTimeStr }) => (
                <div>
                  {roomCreateTimeStr}
                </div>
              )}
            />
          </Table>
          <div className={styles['footer-wrap']}>
            <Button
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button
              type='primary'
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    )
  }
}
export default SelectChatRoom
