/**
 * 
 * 管理员列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Button, Modal, Dropdown, Menu } from 'antd'
import styles from './AdminList.less'
// 引入接口
import { getAdminPageList, setAdminStatus } from './api'
// 引入模块公用组件
import { Filters, CreateAdmin, ResetPassword } from './components'
// 引入公用函数
import { getDate, showSuccess, showError } from '@/utils/base'
// 引入模块公用函数
import { reportStatus, getStatusStr } from './common'
// 引入的图片展示组件
import ZImage from 'react-zmage'
import { connect } from 'dva'

// table 
const Column = Table.Column
const storeName = 'adminListStore'
// 操作下拉menu的样式
const _menuStyle = { width: 100, textAlign: 'center' }
// 操作下拉列表
const getMenu = (_this, record) => (
  <Menu onClick={_this.onActions} align='center' style={_menuStyle}>
    <Menu.Item >
      <a href="#" onClick={e => {
        e.preventDefault()
        _this.onHandle(record)
      }}>
        {record.adminStatus === 1 ? '停用' : '启用'}
      </a>
    </Menu.Item>
    <Menu.Item>
      <a href='#' onClick={e => {
        e.preventDefault()
        _this.onRestpwd(record)
      }}>
        重置密码
      </a>
    </Menu.Item>
    <Menu.Item>
      <a href='#' onClick={e => {
        e.preventDefault()
        _this.onDelete(record)
      }}>
        删除
      </a>
    </Menu.Item>
  </Menu>
)


@connect(({ user }) => ({
  currentUser: user.currentUser
}))
class AdminList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 处理状态
      handleStatus: undefined,
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount() {
    const _state = {}
    if (this.props.location.query.useStore) {
      // 使用本地数据
      const jsonString = sessionStorage[storeName]
      if (jsonString) {
        const json = JSON.parse(jsonString)
        Object.assign(_state, json)
      }
      router.replace({
        pathname: this.props.location.pathname
      })
      sessionStorage.removeItem(storeName)
    }

    this.setState(_state, this.getList)
  }

  // 新增
  onCreate = () => {
    const { currentUser } = this.props
    CreateAdmin({
      agentId: currentUser.agentId,
      onOk: () => {
        showSuccess('管理员新增成功')
        this.getList()
      }
    })
  }

  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { currentUser } = this.props
      const { adminName, adminPhone, handleStatus, startTime, endTime, pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10
      }
      // 公会编号
      if (adminPhone) {
        _params.adminPhone = adminPhone
      }
      // 公会名字
      if (adminName) {
        _params.adminName = adminName
      }
      // 公会状态
      if (handleStatus && handleStatus !== 'all') {
        _params.status = handleStatus
      }
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getAdminPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    this.getList()
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 停启用
  onHandle = ({ adminId, adminStatus }) => {
    const { currentUser } = this.props
    // 是否执行停用操作
    const isStop = adminStatus === 1
    const msg = isStop ? '停用' : '启用'
    Modal.confirm({
      title: `${msg}提示`,
      content: `确定要执行${msg}操作么?`,
      okText: '确定',
      okType: 'primary',
      cancelText: '取消',
      onOk: () => {
        return setAdminStatus({ adminId, adminStatus: isStop ? 0 : 1 })
          .then(({ code }) => {
            if (code === 'OK') {
              showSuccess(msg + '操作执行成功')
              this.getList()
            }
          })
      }
    })
  }
  // 编辑
  onEdit = (record) => {
    CreateAdmin({
      record,
      onOk: () => {
        showSuccess('管理员编辑成功')
        this.getList()
      }
    })
  }

  // 删除
  onDelete = ({ adminId }) => {
    Modal.confirm({
      title: `删除提示`,
      content: `确定要执行删除操作么?`,
      okText: '确定',
      okType: 'primary',
      cancelText: '取消',
      onOk: () => {
        return setAdminStatus({ adminId, adminStatus: -1 })
          .then(({ code }) => {
            if (code === 'OK') {
              showSuccess('删除操作执行成功')
              this.getList()
            }
          })
      }
    })
  }

  // 重置密码
  onRestpwd = ({ adminName, adminPhone, adminId }) => {
    ResetPassword({
      currentUser: {
        adminName, adminPhone, adminId
      }
    })
  }

  render() {
    const {
      loading, list, adminName, adminPhone, handleStatus, pagination,
      startTime, endTime
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize > total
    return (
      <PageHeaderWrapper
        title='管理员列表'
        extra={
          <div>
            <Button
              onClick={this.onCreate}
              type='primary'
              icon='plus'
            >新增管理员</Button>
          </div>
        }
      >
        <Card>
          <Filters
            status={reportStatus}
            onChange={this.onChange}
            adminName={adminName}
            handleStatus={handleStatus}
            adminPhone={adminPhone}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='adminId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
          >
            <Column
              title='名称'
              key='adminName'
              dataIndex='adminName'
            />
            {/* <Column 
              title='头像'
              key='adminAvatar'
              dataIndex='adminAvatar'
              render={(text, { adminAvatar}) => (
                adminAvatar
                ? <ZImage src={adminAvatar} style={{width: 60}} />
                : '-'
              )}
            /> */}
            <Column
              title='手机号'
              key='adminPhone'
              dataIndex='adminPhone'
            />
            <Column
              title='邮箱'
              key='adminEmail'
              dataIndex='adminEmail'
              render={(text, { adminEmail }) => (
                <div>{adminEmail ? adminEmail : '-'}</div>
              )}
            />
            <Column
              title='状态'
              key='adminStatus'
              dataIndex='adminStatus'
              render={(text, { adminStatus }) => (
                <div>{getStatusStr(adminStatus)}</div>
              )}
            />
            <Column
              title='创建时间'
              key='adminCreateTime'
              dataIndex='adminCreateTime'
              render={(text, { adminCreateTime }) => (
                <div>
                  {adminCreateTime && adminCreateTime !== '0' ? getDate(+adminCreateTime, 'yyyy-MM-dd hh:mm') : '-'}
                </div>
              )}
            />
            <Column
              title='操作'
              key='actions'
              dataIndex='actions'
              align='center'
              render={(text, record) => (
                <div className={styles['list-actions']}>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.onEdit(record)
                  }}>编辑</a>
                  <Divider type='vertical' />
                  <Dropdown overlay={getMenu(this, record)} placement='bottomCenter'>
                    <a href="#" onClick={e => {
                      e.preventDefault()
                    }}>更多</a>
                  </Dropdown>
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default AdminList
