/**
 * 
 * 新建/编辑 管理员
 */

// 引入react依赖
import React, { Component } from 'react'
// 引入antd组件
import { Drawer, Select, Table, Button, Switch, Form, Input } from 'antd'
// 引入样式
import styles from './CreateAdmin.less'
// 引入需要的公共方法
import { getDate, showError, encryptMd5 } from '@/utils/base'
// 引入当前模块需要的接口函数
import { editAdmin, createAdmin } from '../../api'
// 引入上传图片组件
import MyUpload from '@/components/Custom/MyUpload'

// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}

// 表单响应配置
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 4 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 18 },
  },
}

// Form 
@Form.create()
class CreateAdmin extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // loading
      loading: false,
      // 管理员头像
      fileList: []
    }

    // 上传头像组件的 this
    this.adminAvatar = null
  }
  componentDidMount () {
    const { record } = this.props
    const _state = {}
    const _fileds = {}
    if (record) {
      _fileds.adminName = record.adminName
      _fileds.adminPhone = record.adminPhone
      _fileds.adminEmail = record.adminEmail
      // 密码造个假的
      _fileds.adminPass = '123456' // record.adminPass
      _fileds.adminStatus = record.adminStatus === 1 ? true : false
      if (record.adminAvatar) {
        _state.fileList = [{ url: record.adminAvatar, uid: '123uddkks' }]
      }
      this.setState(_state, () => {
        this.props.form.setFieldsValue(_fileds)
      })
    }
  }
  
  onOk = () => {
    const { form, record, agentId } = this.props
    const { fileList } = this.adminAvatar.state
    form.validateFieldsAndScroll((errors, values) => {
      if (errors) {
        return
      }
      const { adminPass, adminStatus, ...others } = values
      const params = others
      if (agentId) {
        params.agentId = agentId
      }
      params.adminPass = encryptMd5(adminPass)
      // if (fileList && fileList.length) {
      //   params.adminAvatar = fileList[0].url
      // } else {
      //   params.adminAvatar = ''
      // }
      params.adminStatus = adminStatus ? 1 : 0
      if (record) {
        params.adminId = record.adminId
        // 手机号和密码不能修改
        Reflect.deleteProperty(params, 'adminPass')
        Reflect.deleteProperty(params, 'adminPhone')
      }
      this.onPost(params)
    })
  }

  // 上传数据
  onPost = async (params) => {
    const { record } = this.props
    let _code = ''
    try {
      this.setState({ uploading: true })
      const { code } = record ? await editAdmin(params) : await createAdmin(params)
      _code = code
    } catch (e) {
      console.log(e)
    }
    this.setState({ uploading: false })
    if (_code === 'OK') {
      const { onOk } = this.props 
      onOk && onOk()
    }
  }
  render () {
    const { onCancel, form, record } = this.props
    const { loading, fileList, uploading  } = this.state
    const { getFieldDecorator } = form
    // { getFieldDecorator: function () {} }
    return (
      <Drawer
        title={`${record ? '编辑' : '新建'}管理员`}
        onClose={onCancel}
        visible
        width={620}
      >
        <div className={styles['content-wrap']}>
          <div>
            <Form {...formItemLayout}>
              <Form.Item
                label='名称'
              >
                {getFieldDecorator('adminName', {
                  rules: [{ required: true, message: '请输入管理员名称', whitespace: true }],
                })(
                  <Input 
                    placeholder='请输入管理员名称'
                  />
                )}
              </Form.Item>
              <Form.Item
                label='手机号'
              >
                {getFieldDecorator('adminPhone', {
                  rules: [{ required: true, message: '请输入管理员手机号', whitespace: true }],
                })(
                  <Input 
                    placeholder='请输入管理员手机号'
                    disabled={!!record}
                  />
                )}
              </Form.Item>
              <Form.Item
                label='密码'
              >
                {getFieldDecorator('adminPass', {
                  rules: [{ required: true, message: '请输入管理员密码', whitespace: true }],
                })(
                  <Input 
                    placeholder='请输入管理员密码'
                    disabled={!!record}
                    type={!!record ? 'password': 'text'}
                  />
                )}
              </Form.Item>
              <Form.Item
                label='邮箱'
              >
                {getFieldDecorator('adminEmail', {
                  rules: [{ required: false, message: '请输入管理员邮箱', whitespace: true }],
                })(
                  <Input 
                    placeholder='请输入管理员邮箱'
                  />
                )}
              </Form.Item>
              <Form.Item
                label='头像'
                hidden
              >
                <MyUpload 
                  num={1} 
                  saveData={(_this) => {this.adminAvatar = _this}}
                  fileList={fileList}
                />
              </Form.Item>
              <Form.Item
                label='停/启用'
              >
                {getFieldDecorator('adminStatus', {
                  initialValue: true,
                  valuePropName: 'checked'
                })(
                  <Switch 
                    checkedChildren='启用'
                    unCheckedChildren='停用'
                  />
                )}
              </Form.Item>
            </Form>
          </div>
          <div className={styles['footer-wrap']}>
            <Button 
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button 
              type='primary' 
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    )
  }
}
export default CreateAdmin
