/**
 * 
 * 管理员列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './Filters.less'
import { Select, Input, Button, DatePicker, InputNumber } from 'antd'
import moment from 'moment'
import { regIntNumber } from '@/utils/base'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onAdminPhone = (e) => {
    const { value } = e.target
    if (value && !regIntNumber.test(value)) {
      return
    }
    const { onChange } = this.props
    onChange && onChange('adminPhone', value)
  }
  onAdminName = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('adminName', value)
  }
  // 状态改变
  onStatusChange = key => {
    const { onChange } = this.props
    onChange && onChange('handleStatus', key)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { status, onSearch, adminName, handleStatus, adminPhone, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>管理员名:</h4>
          <Input 
            placeholder='请输入管理员名称'
            style={_style}
            value={adminName}
            onChange={this.onAdminName}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>手机号:</h4>
          <Input
            placeholder='请输入手机号'
            style={_style}
            value={adminPhone}
            onChange={this.onAdminPhone}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>状态:</h4>
          <Select
            style={_style}
            placeholder='请选择状态'
            value={handleStatus}
            onChange={this.onStatusChange}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              status && status.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
