/**
 * 
 * 主播详情
 */
import React from 'react';
import { Row, Col, Descriptions, Badge, Card, List, Typography, Alert, Button, Menu, Dropdown, Icon, Modal, notification } from 'antd';
import { getAnchorDetail, getAnchorAuditRecord } from '@/services/manage';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import Url from '@/utils/Url';
import * as Format from '@/utils/Format';
import Zmage from 'react-zmage';
import Ellipsis from '../../components/Ellipsis';
import router from 'umi/router';
import styles from './AnchorDetail.less'
import LiveRecords from './components/LiveRecords'
import { DetailSingleInfo } from './components'
import { SingChatRecord } from '@/components/PageContent'

const { Paragraph } = Typography;

class AnchorDetail extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      userId: Url.getQueryString('userId'),
      info: { userProfile: {} },
      auditList: [],
      agentInfo: {},
      // 是否是1v1主播
      isSingleAnchor: false,
      // isSingleAnchor: props.location.pathname.indexOf('listsingle') !== -1
    };
  }

  componentDidMount() {
    this.getAnchorDetail(); //获取主播详情
    this.getAnchorAuditRecord()   //认证记录

  }

  //认证记录
  getAnchorAuditRecord() {
    const { auditLoading, userId } = this.state;
    this.setState({ auditLoading: true }, async () => {
      const res = await getAnchorAuditRecord({ userId });
      if (res.success) {
        const auditList = res.data || []
        this.setState({ auditLoading: false, auditList });
      } else {
        this.setState({ auditLoading: false });
      }
    });
  }

  //获取主播详情
  getAnchorDetail() {
    const { loading, userId } = this.state;
    this.setState({ loading: true }, async () => {
      const res = await getAnchorDetail({ userId });
      if (res.success) {
        const info = res.data || {};
        info.userProfile = info.userProfile || {};
        // 计算平均分
        if (info.singleChatScore && info.singleChatEvaluateTimes) {
          info.singleChatScoreAverage = (info.singleChatScore / info.singleChatEvaluateTimes).toFixed(2)
        } else {
          info.singleChatScoreAverage = 0
        }
        this.setState({ loading: false, info, isSingleAnchor: info.singleChatEnable === 1 });
      } else {
        this.setState({ loading: false });
      }
    });
  }

  testLog() {
    console.log(this.state);
  }

  // renderAgentTitle = () => {
  //   const { info } = this.state
  //   const menu = (
  //     <Menu>
  //       <Menu.Item onClick={this.unBindAgent}>
  //         解绑公会
  //       </Menu.Item>
  //     </Menu>
  //   )
  //   return (
  //     <div>
  //       <span>公会信息</span>
  //       {info.agentId && (
  //         <Dropdown overlay={menu} placement="topCenter" trigger={['click']}>
  //           <Icon type="setting" style={{ color: '#1890ff', marginLeft: 20 }} />
  //         </Dropdown>
  //       )}
  //     </div>
  //   )
  // }

  //解绑主播公会
  // unBindAgent = () => {
  //   const { info } = this.state
  //   Modal.confirm({
  //     title: '确定解绑主播公会吗?',
  //     okText: '确定解绑',
  //     okType: 'danger',
  //     cancelText: '取消',
  //     onOk: async () => {
  //       const res = await unBindAgent({ userId: info.userId })
  //       if (res.success) {
  //         notification.success({
  //           message: '解绑公会成功'
  //         })
  //         info.agentId = ''
  //         this.setState({ agentInfo: {}, info })
  //       }
  //     }
  //   });
  // }

  render() {
    const { loading, info, agentInfo, userId, isSingleAnchor, records } = this.state
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>主播详情</span>}
        onBack={() => router.goBack()}
        className={styles.anchorDetail}
        extra={
          <div>
            <Button icon='left' onClick={router.goBack}>返回</Button>
          </div>
        }
      >
        <Card loading={loading}>
          <Descriptions title="基础信息">
            <Descriptions.Item label="头像">
              <Zmage
                style={{ width: 50, height: 50, borderRadius: '50%' }}
                src={info.userProfile.userAvatar}
              ></Zmage>
            </Descriptions.Item>
            <Descriptions.Item label="名称">{info.userName}</Descriptions.Item>
            <Descriptions.Item label="ID">{info.userName}</Descriptions.Item>
            <Descriptions.Item label="手机号">{info.userProfile.userPhone || '暂无'}</Descriptions.Item>
            <Descriptions.Item label="等级">{info.charmLevel}</Descriptions.Item>
            <Descriptions.Item label="魅力值">{info.charmValue}</Descriptions.Item>
            <Descriptions.Item label="个性签名">
              <Ellipsis tooltip length={20} style={{ display: 'contents' }}>
                {info.userProfile.userSign}
              </Ellipsis>
            </Descriptions.Item>
            <Descriptions.Item label="粉丝数量">{info.fansCount}</Descriptions.Item>
            <Descriptions.Item label="创建时间">
              {Format.date(info.userCreateTime, 'yyyy-MM-dd HH:mm')}
            </Descriptions.Item>
            <Descriptions.Item label="审核时间">
              {Format.date(info.anchorAuthTime, 'yyyy-MM-dd HH:mm')}
            </Descriptions.Item>
            <Descriptions.Item label="直播状态">
              {info.liveStatus === 101 && <Badge status="processing" text="直播中" />}
              {info.liveStatus === 201 && <Badge status="default" text="未开播" />}
            </Descriptions.Item>
            <Descriptions.Item label="推流状态">
              {info.streamStatus === 101 && <Badge status="processing" text="推流中" />}
              {info.streamStatus === 201 && <Badge status="default" text="已关闭" />}
            </Descriptions.Item>

            <Descriptions.Item label="启用单聊匹配">
              {info.singleChatMatchEnable === 1 && <Badge status="success" text="开启中" />}
              {(info.singleChatMatchEnable === 0 || !info.singleChatMatchEnable) && <Badge status="default" text="已关闭" />}
            </Descriptions.Item>
            <Descriptions.Item label="pk开关">
              {info.battleEnable === 1 && <Badge status="success" text="开启中" />}
              {info.battleEnable === 0 && <Badge status="default" text="已关闭" />}
            </Descriptions.Item>
            <Descriptions.Item label="是否在pk中">
              {info.battling === 1 && <Icon type="check" style={{ color: '#1fb922' }} />}
              {info.battling === 0 && <Icon type="close" style={{ color: '#999' }} />}
            </Descriptions.Item>
            <Descriptions.Item label="Pk次数">
              <Row type="flex" align="middle" className={styles['battle-bar']}>
                <div style={{ marginRight: 10 }}>{info.battleTimes}</div>
                <Row type="flex">
                  <div className={styles.win}>{info.battleWinTimes}胜</div>
                  <div className={styles.draw}>{info.battleDrawTimes}平</div>
                  <div className={styles.loss}>{info.battleLossTimes}负</div>
                </Row>
              </Row>
            </Descriptions.Item>
          </Descriptions>

          <Descriptions title="封面" className="descriptions-cover">
            <Descriptions.Item label="直播封面">
              <Zmage
                style={{ width: 60 }}
                src={info.liveCover}
              ></Zmage>
            </Descriptions.Item>
            <Descriptions.Item label="颜值封面">
              {info.userCover ? (
                <Zmage
                  style={{ width: 200, verticalAlign: 'top' }}
                  src={info.userCover}
                ></Zmage>
              ) : '暂未设置'}
            </Descriptions.Item>
          </Descriptions>
        </Card>

        {isSingleAnchor && <DetailSingleInfo info={info} />}
        <SingChatRecord userId={userId} />

        {/* <Card title={this.renderAgentTitle()}>
          {Object.keys(agentInfo).length > 0 ? (
            <Descriptions >
              <Descriptions.Item label="公会名称">{agentInfo.agentName}</Descriptions.Item>
              <Descriptions.Item label="公会ID">{agentInfo.agentId}</Descriptions.Item>
              <Descriptions.Item label="会长">{agentInfo.presidentName}</Descriptions.Item>
              <Descriptions.Item label="会长ID">{agentInfo.presidentUserNo}</Descriptions.Item>
              <Descriptions.Item label="入族时间">{Format.date(agentInfo.signTime, 'yyyy-MM-dd HH:mm')}</Descriptions.Item>
            </Descriptions>
          ) : (
              <Alert message="暂未加入公会" type="info" showIcon />
            )}
        </Card> */}

        {/* <Card title="直播信息">
          
        </Card> */}
        <Card title="认证记录">
          <List
            bordered
            loading={this.state.auditLoading}
            dataSource={this.state.auditList}
            renderItem={item => (
              <AuditItem info={item} />
            )}
          />
        </Card>
        <LiveRecords userId={userId} />
      </PageHeaderWrapper>
    );
  }
}

export default AnchorDetail;

function AuditItem(props) {
  const info = props.info
  return (
    <List.Item style={{ display: 'block' }}>
      <Paragraph>申请时间：{Format.date(info.applyTime, 'yyyy-MM-dd HH:mm')}</Paragraph>
      <Paragraph>审核时间：{Format.date(info.auditTime, 'yyyy-MM-dd HH:mm')}</Paragraph>
      <Paragraph>
        <span>审核结果：</span>
        {info.auditStatus === 0 && <Badge status="processing" text="待审核" />}
        {info.auditStatus === 1 && <Badge status="success" text="通过" />}
        {info.auditStatus === 2 && <Badge status="error" text="拒绝" />}
      </Paragraph>
      <Paragraph>
        审核备注：{info.auditMsg || '--'}
      </Paragraph>
      <Paragraph>审核人：{info.adminName || '--'}</Paragraph>
      <Row type="flex" style={{ textAlign: 'center' }}>
        <Col>
          <Zmage
            style={{ width: 100 }}
            src={info.idCardHoldImg}
          ></Zmage>
          <div>手持身份证照片</div>
        </Col>
        <Col style={{ margin: '0px 20px' }}>
          <Zmage
            style={{ width: 100 }}
            src={info.idCardFaceImg}
          ></Zmage>
          <div>身份证正面照</div>
        </Col>
        <Col>
          <Zmage
            style={{ width: 100 }}
            src={info.idCardNationImg}
          ></Zmage>
          <div>身份证反面照</div>
        </Col>
      </Row>
    </List.Item>
  )
}
