/**
 * 
 * 主播列表
 */
import React, { Component, Fragment } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Icon, Modal, Menu, Dropdown, Badge }  from 'antd' 
import styles from './AnchorAuditList.less'
// 引入接口
import { getAnchorPageList } from './api'
// 引入模块公用组件
import { Filters } from './components'
// 引入公用函数
import { getDate } from '@/utils/base'
// 引入connect
import { connect } from 'dva'
// 引入当前模块公用方法
import { getAuditStatus } from './common'
import Zmage from 'react-zmage'
import Ellipsis from '@/components/Ellipsis'
import defaultAvatar from '@/assets/user_icon.png'

// table 列组件
const Column = Table.Column
// 本地存储key
const storeName = 'anchorAuditListStore'
// 列表组件
@connect(({ user }) => ({
  currentUser: user.currentUser
}))
class AnchorAuditList extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    const _state = {}
    // 地址中存在 useStore 的值将从本地获取state数据
    if (this.props.location.query.useStore) {
      // 使用本地数据
      const jsonString = sessionStorage[storeName]
      // 解析本地json数据
      if (jsonString) {
        const json = JSON.parse(jsonString)
        // 合并到state
        Object.assign(_state, json)
      }
      // 去除地址拦中query的变量
      router.replace({
        pathname: this.props.location.pathname
      })
      // 移除本地数据
      sessionStorage.removeItem(storeName)
    }
    
    this.setState(_state, this.getList)
  }
  
  // 获取列表
  getList = async () => {
    const { agentId } = this.props.currentUser
    if (!agentId) {
      return
    }
    const _state  = {
      loading: false
    }
    try {
      const { 
        streamStatus, userName, liveStatus, startTime, endTime, pagination,
        charmLevel, userNo, userPhone
       } = this.state
      // 页码，每页条数
      const _params = {
        pageNum: pagination.current || 1,
        pageSize: 20,
        agentId
      }
      // 用户名
      if (userName) {
        _params.userName = userName
      }

      // 推流状态
      if (streamStatus && streamStatus !== 'all') {
        _params.streamStatus = streamStatus
      }

      // 直播状态
      if (liveStatus) {
        _params.liveStatus = liveStatus
      }

      // 主播等级
      if (charmLevel || charmLevel === 0) {
        _params.charmLevel = charmLevel
      }

      // ID
      if (userNo) {
        _params.userNo = userNo
      }

      // 手机号
      if (userPhone) {
        _params.userPhone = userPhone
      }
    
      // 开始结束时间
      if (startTime) {
        _params.startDate = startTime
        _params.endDate = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getAnchorPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        // list && list.map((item) => {
          // console.log(item.anchorRatio)
          // item.anchorRatioStr = this.formatRatio(item.anchorRatio)
        // })
        // 列表数据
        _state.list = list
        // 页码信息
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  goDetails = ({ userId }) => {
    sessionStorage[storeName] = JSON.stringify(this.state)
    router.replace({
      pathname: this.props.location.pathname,
      query: {
        useStore: 1
      }
    })
    router.push({
      pathname: '/anchors/list/details',
      query: {
        userId
      }
    })
  }
  render () {
    const { 
      loading, list, userName, pagination, startTime, endTime, applyType,
      auditStatus, liveStatus, streamStatus, charmLevel, userNo, userPhone
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper title='主播列表'>
        <Card>
          <Filters 
            applyType={applyType}
            auditStatus={auditStatus}
            onChange={this.onChange}
            userName={userName}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
            liveStatus={liveStatus}
            streamStatus={streamStatus}
            charmLevel={charmLevel}
            userNo={userNo}
            userPhone={userPhone}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey={(auditId, applyTime) => `${auditId}-${applyTime}`}
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
            className='table-wrap'
          >
            <Column
              title="头像"
              dataIndex="userAvatar"
              key="userAvatar"
              render={userAvatar => (
                <Zmage width={40} src={userAvatar || defaultAvatar } />
              )}
            />
            <Column
              title="名称"
              key="userName"
              dataIndex="userName"
              render={userName => (
                <Ellipsis tooltip length={20}>
                  {userName}
                </Ellipsis>
              )}
            />
            <Column
              title="性别"
              key="userSex"
              dataIndex="userSex"
              render={userSex => (
                userSex === 1 
                ? <Icon type="man" style={{ color: '#1890ff' }}/> 
                : <Icon type="woman" style={{ color: '#eb2f96' }}/>
              )}
            />
            <Column
              title="UserID"
              key="userId"
              dataIndex="userId"
            />
            <Column
              title="ID"
              key="userNo"
              dataIndex="userNo"
            />
            <Column
              title="等级"
              key="charmLevel"
              dataIndex="charmLevel"
            />
            <Column
              title="魅力值"
              key="charmValue"
              dataIndex="charmValue"
            /> 
            <Column
              title="手机号"
              key="userPhone"
              dataIndex="userPhone"
            />
            <Column
              title="粉丝数量"
              key="fansCount"
              dataIndex="fansCount"
            />
            <Column
              title="主播状态"
              key="disable"
              dataIndex="disable"
              render={(disable, record) => (
                <Fragment>
                  {!disable && <Badge status="success" text="正常" />}
                  {disable && (
                    <Tooltip placement="topLeft" 
                      title={
                        record.enableTime === -1 
                        ? '永久禁播' 
                        : `禁播至：${getDate(parseInt(record.enableTime), 'yyyy-MM-dd hh:mm')}`
                      }
                    >
                      <Badge status="error" text="禁播中" />
                    </Tooltip>
                  )}
                </Fragment>
              )}
            />
            <Column
              title="直播状态"
              key="liveStatus"
              dataIndex="liveStatus"
              render={liveStatus => (
                <Fragment>
                  {liveStatus === 101 && <Badge status="processing" text="直播中" />}
                  {liveStatus === 201 && <Badge status="default" text="未开播" />}
                </Fragment>
              )}
            />
            <Column
              title="推流状态"
              key="streamStatus"
              dataIndex="streamStatus"
              render={streamStatus => (
                <Fragment>
                  {streamStatus === 101 && <Badge status="processing" text="推流中" />}
                  {streamStatus === 201 && <Badge status="default" text="已关闭" />}
                </Fragment>
              )}
            />
            <Column
              title="审核时间"
              dataIndex="anchorAuthTime"
              key="anchorAuthTime"
              render={anchorAuthTime => (
                <div>{anchorAuthTime ? getDate(+anchorAuthTime, 'yyyy-MM-dd hh:mm') : '-'}</div>
              )}
            />
            <Column 
              title='操作'
              key='actions'
              dataIndex='actions'
              align='center'
              render={(text, record) => (
                <div className={styles['list-actions']}>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.goDetails(record)
                  }}>详情</a>
                </div>
              )}
            /> 
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default AnchorAuditList
