/**
 * 
 * 主播列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './Filters.less'
import { Select, Input, Button, DatePicker, InputNumber } from 'antd'
import moment from 'moment'
import { regIntNumber } from '@/utils/base'
import { streamStatusArray, auditStatus as auditStatusArray, liveStatusArray } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onInput = name => (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange(name, value)
  }
  onInputNumber = name => (value) => {
    const { onChange } = this.props
    onChange && onChange(name, value)
  }
  onUserName = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('userName', value)
  }
  onSelectChange = name => key => {
    const { onChange } = this.props
    onChange && onChange(name, key)
  }
  // 状态申请类型
  onApplyType = key => {
    const { onChange } = this.props
    onChange && onChange('applyType', key)
  }
  // 审核状态
  onAuditStatus = key => {
    const { onChange } = this.props
    onChange && onChange('auditStatus', key)
  }
  // 时间筛选
  onDateChange = (moments, strArray) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf() // new Date(strArray[0] + ' 00:00:00').getTime() // moments[0].valueOf()
      _endTime = moments[1].valueOf() // new Date(strArray[1] + ' 23:59:59').getTime() // moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { 
      liveStatus, onSearch, streamStatus, userName, startTime, endTime,
      charmLevel, userNo, userPhone
    } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>主播昵称:</h4>
          <Input 
            placeholder='请输入主播昵称'
            style={_style}
            value={userName}
            onChange={this.onUserName}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>直播状态:</h4>
          <Select
            style={_style}
            placeholder='请选择直播状态'
            value={liveStatus}
            onChange={this.onSelectChange('liveStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              liveStatusArray && liveStatusArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>推流状态:</h4>
          <Select
            style={_style}
            placeholder='请选择推流状态'
            value={streamStatus}
            onChange={this.onSelectChange('streamStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              streamStatusArray && streamStatusArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>主播等级:</h4>
          <Input
            allowClear 
            type='number' 
            placeholder="请输入主播等级" 
            addonAfter="级" 
            value={charmLevel}
            onChange={this.onInput('charmLevel')}
            min={0}
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>ID:</h4>
          <InputNumber
            allowClear 
            placeholder="请输入ID" 
            value={userNo}
            onChange={this.onInputNumber('userNo')}
            min={0}
            style={{width: '100%'}}
            precision={0}
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>手机号:</h4>
          <Input
            allowClear 
            placeholder="请输入手机号" 
            value={userPhone}
            onChange={this.onInput('userPhone')}
            min={0}
          />
        </div>
        
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`}>
          <h4 className={styles['filter-label']}>审核时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
            showTime
          />
        </div>
        <div className={styles['btn-wrap']}>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
