/**
 * 
 * 直播记录
 */
import React, { Component } from 'react'
import { Card, Table, Divider }  from 'antd' 
import styles from './LiveRecords.less'
// 引入接口
import { getLiveHisPageList } from '@/services/manage'
// 引入公用函数
import { getDate } from '@/utils/base'
// 查看回放
import VideoReview from './VideoReview'
// 推流记录
import ShowPushStreams from './ShowPushStreams'

// table 
const Column = Table.Column

class LiveRecords extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      pagination: {
        current: 1
      },
    }
  }
  componentDidMount () {
    this.getList()
  }
  
  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      // 主播id
      const { userId } = this.props
      const { pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10,
        userId
      }

      this.setState({ loading: true })
      const { data, code } = await getLiveHisPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        list && list.forEach((item) => {
          // 格式化直播时长
          item.liveDurationStr = this.formatStamp(item.liveDuration)
          // 格式化有效直播时长
          item.liveEffectiveDurationStr = this.formatStamp(item.liveEffectiveDuration)
        })
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  // 格式化时间
  formatStamp = (stamp) => {
    if (!stamp) {
      return '-'
    }
    // 现转换成秒
    const baseStamp = parseInt(stamp / 1000) 
    // 获取时
    const h = parseInt(baseStamp / 3600)
    // 秒对时取余 以便获取分
    const baseMin = baseStamp % 3600
    // 获取分
    const m = parseInt(baseMin / 60)
    // 获取秒
    const s = baseMin % 60
    return `${h}小时${m}分${s}秒`
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 查看回放
  onReview = (record) => {
    VideoReview({
      record
    })
  }

  // 查看推流记录
  onPushReview = (record) => {
    ShowPushStreams({
      record
    })
  }

  render () {
    const { 
      loading, list, pagination
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total

    return (
      <Card title='直播记录'>
        <Table
          loading={loading}
          dataSource={list}
          rowKey='hisId'
          onChange={this.onPageChange}
          bordered
          pagination={hidePagination ? false : pagination}
        >
          <Column 
            title='最高人气'
            key='liveMaxPopularity'
            dataIndex='liveMaxPopularity'
          />
          <Column 
            title='最高热度值'
            key='liveHeatMax'
            dataIndex='liveHeatMax'
          />
          <Column 
            title='开播时间'
            key='liveStartTime'
            dataIndex='liveStartTime'
            render={(text, { liveStartTime }) => (
              <div>{liveStartTime ? getDate(+liveStartTime) : '-'}</div>
            )}
          />
          <Column 
            title='下播时间'
            key='liveStopTime'
            dataIndex='liveStopTime'
            render={(text, { liveStopTime }) => (
              <div>{liveStopTime ? getDate(+liveStopTime) : '-'}</div>
            )}
          />
          <Column 
            title='直播时长'
            key='liveDurationStr'
            dataIndex='liveDurationStr'
          />
          <Column 
            title='直播有效时长'
            key='liveEffectiveDurationStr'
            dataIndex='liveEffectiveDurationStr'
          />
          
          <Column 
            title='是否超时下播'
            key='liveIsTimeout'
            dataIndex='liveIsTimeout'
            render={(text, { liveIsTimeout }) => (
              liveIsTimeout === 1 ? '是' : '否'
            )}
          />
          <Column 
            title='直播收益'
            key='liveCoinIncome'
            dataIndex='liveCoinIncome'
          />
          <Column 
            title='创建时间'
            key='hisCreateTime'
            dataIndex='hisCreateTime'
            render={(text, { hisCreateTime }) => (
              <div>{hisCreateTime ? getDate(+hisCreateTime) : '-'}</div>
            )}
          />
          <Column 
            title='操作'
            key='actions'
            dataIndex='actions'
            align='center'
            render={(text, record) => (
              <div className={styles['list-actions']}>
                <a href="#" onClick={ e=> {
                  e.preventDefault()
                  this.onPushReview(record)
                } }>推流记录</a>
                <Divider type="vertical"/>
                <a href="#" onClick={ e=> {
                  e.preventDefault()
                  this.onReview(record)
                } }>查看回放</a>
              </div>
            )}
          />
        </Table>
      </Card>
    )
  }
}
export default LiveRecords
