/**
 * 
 * 视频回放
 */
import React, { Component } from 'react'
import { Modal, Select, Form, Radio, Result } from 'antd'
import styles from './VideoReview.less'
import { getLiveStreamHis, getLiveHis } from '@/services/manage'
// import startTransform from './transform'
import ReactPlayer from 'react-player'

const _style = {
  width: '100%'
}

// 'http://pili-vod.test.qn.haoyipai.com/fragments/z1.starbuds-test.18077106307101/1578018185683-1578018194967.ts'

class VideoReview extends Component {
  constructor (props) {
    super(props)
    this.state = {}
  }
  componentDidMount () {
    const { record } = this.props 
    if (record && record.hisId) {
      this.onInit(record)
    } 
  }

  onInit = async ({ hisId }) => {
    const _state = {
      loading: false
    }
    try {
      this.setState({ loading: true })
      const streamRes = await getLiveStreamHis({
        liveHisId: hisId
      })
      // const detailRes = await getLiveHis({
      //   hisId
      // })
      if (streamRes.code === 'OK' && streamRes.data) {
        const videoArray = streamRes.data
        _state.videoArray = videoArray
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 点击确定 上传数据
  onOk = () => {
    const { onOk }  = this.props 
    onOk && onOk()
  }
  
  render () {
    const { videoArray, loading } = this.state
    const videoArrayLen = videoArray ? videoArray.length : 0
    // 'http://upload.junfengshow.com/video/mda-iitj5pxg3meizmrj.mp4'
    return (
      <Modal
        title='视频回放'
        onCancel={this.props.onCancel}
        onOk={this.onOk}
        visible
        okText={'知道了'}
      >
        <div>
          {
            !loading && videoArrayLen === 0
            ? <div>
              <Result 
                status='error'
                title='视频不存在'
              />
            </div>
            : videoArray && videoArray.map((item, i) => (
              <div key={i}>
                <h4>视频{i + 1}:</h4>
                <VideoContent url={item.hisVodUrl} />
              </div>
            ))
          }
        </div>
      </Modal>
    )
  }
}

class VideoContent extends Component {
  constructor (props) {
    super(props)
    this.state = {
      isError: false,
      isNoVideo: !props.url
    }
  }
  componentDidMount () {
    const { url } = this.props
    const { isNoVideo } = this.state
    
    if (isNoVideo) {
      this.setState({
        isNoVideo: true
      })
      return
    }
    // ts文件转码
    // startTransform(url, this.videoContainer, {
    //   errorCallback: () => {
    //     this.setState({ isError: true })
    //   }
    // })
  }
  onError = () => {
    this.setState({ isError: true })
  }
  componentWillUnmount () {
    // this.player && this.player.dispose()
    this.player && this.player.destroy()
  }
  render () {
    const { isError, isNoVideo } = this.state
    const { url } = this.props
    // item.hisVodUrl
    return (
      isNoVideo
      ? <div>
        <Result 
          status='error'
          title='视频不存在'
        />
      </div>
      : <React.Fragment>
        <div hidden={!isError} className={styles['video-error-wrap']}>
          <Result 
            status='error'
            title='播放失败'
            subTitle='当前直播回放播放失败'
          />
        </div>
        <div hidden={isError} id='video-wrapper' className={styles['video-wrap']} ref={node => this.videoContainer = node}>
          <ReactPlayer
            url={url}
            controls
            playing
            width='100%'
            height='100%'
          />
          {/* <video 
            src={url}
            onError={this.onError}
            controls
          /> */}
        </div>
      </React.Fragment>
    )
  }
}

export default VideoReview
