/**
 * 
 * 语音房详情
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Button, Descriptions, Table } from 'antd'
import styles from './ChatRoomDetails.less'
import router from 'umi/router'
import { getRtcRoomDetail } from './api'
import { getChatRoomStatusStr } from './common'
import { getDate, getChatRoomRoleStr, getChatRoomTypeStr, showSuccess } from '@/utils/base'
import ZImage from 'react-zmage'
import { CRDetailCount, SetRoomNo } from './components'

const Column = Table.Column
const _cardStyle = {
  marginBottom: 10
}

class ChatRoomDetails extends Component {
  constructor (props) {
    super(props)
    this.state = {
      roomId: props.location.query.roomId
    }
  }
  componentDidMount () {
    this.getDetails()
  }
  getDetails = async () => {
    const { roomId } = this.state 
    if (!roomId) {
      return
    }
    const _state = {}
    try {
      const { code, data } = await getRtcRoomDetail({ roomId })
      if (code === 'OK' && data) {
        const { roomRoleList } = data 
        roomRoleList && roomRoleList.forEach((item) => {
          item.roomRoleName = getChatRoomRoleStr(item.roomRole)
        })
        Object.assign(_state, data, {
          roomStatusStr: getChatRoomStatusStr(data.status),
          roomCreateTimeStr: getDate(+data.roomCreateTime),
          roomTypeStr: getChatRoomTypeStr(data.roomType),
          roomRoleList,
        })
      }
    } catch (e) {}
    this.setState(_state)
  }
  goBack = () => {
    router.goBack()
  }
  /**
   * 设置房间编号
   */
  onRoomNoSet = () => {
    const { roomNo, roomId } = this.state
    SetRoomNo({
      roomNo, 
      roomId,
      onOk: () => {
        showSuccess('房间编号设置成功')
        this.getDetails()
      }
    })
  }
  render () {
    const { 
      // 房间封面
      roomCover,
      // 房间名称
      roomName,
      roomNo,
      roomId,
      // 房间状态
      roomStatusStr,
      // 创建人
      userName,
      // 创建时间
      roomCreateTimeStr,
      // 角色列表
      roomRoleList,
      // 房间标题
      roomTitle,
      // 房间规则
      roomRule,
      // 欢迎语
      roomWelcome,
      // 房间锁密码
      roomLockPass,
      // 是否自由上麦
      roomMicFree,
      // 心动值开关
      roomScoreEnabled,
      // 公屏开关
      roomChatEnabled,
      // 房间背景
      backgroundUrl,
      // 类目
      categoryName,
      // 房间类型
      roomTypeStr,
      // 是否热门
      hotEnable,
    } = this.state
    return (
      <PageHeaderWrapper
        title='聊天室详情'
        extra={
          <div>
            <Button icon='left' onClick={this.goBack}>返回</Button>
          </div>
        }
      >
        <Card title='房间基本信息' style={_cardStyle}>
          <Descriptions bordered>
            <Descriptions.Item label='房间名称'>
              {roomName}
            </Descriptions.Item>
            <Descriptions.Item label='房间编号'>
              <span className={styles['room-no']}>{roomNo}</span>
              {/* <Button 
                type="primary" 
                ghost size="small" 
                icon="edit" 
                onClick={this.onRoomNoSet}
              >设置</Button> */}
            </Descriptions.Item>
            <Descriptions.Item label='房间状态'>
              {roomStatusStr}
            </Descriptions.Item>

            <Descriptions.Item label='房间封面'>
              {roomCover ? <ZImage src={roomCover} style={{ width: 60 }} />: '-'}
            </Descriptions.Item>
            <Descriptions.Item label='房间类型'>
              {roomTypeStr}
            </Descriptions.Item>
            <Descriptions.Item label='房间类目'>
              {categoryName}
            </Descriptions.Item>

            <Descriptions.Item label='房间背景'>
              {backgroundUrl ? <ZImage src={backgroundUrl} style={{ width: 60 }} />: '-'}
            </Descriptions.Item>
            <Descriptions.Item label='创建人'>
              {userName}
            </Descriptions.Item>
            <Descriptions.Item label='创建时间'>
              {roomCreateTimeStr}
            </Descriptions.Item>

            <Descriptions.Item label='房间标题'>
              {roomTitle || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='房间规则'>
              <div style={{maxWidth: 400}}>
                {roomRule || '-'}
              </div>
            </Descriptions.Item>
            <Descriptions.Item label='欢迎语'>
              {roomWelcome || '-'}
            </Descriptions.Item>

            <Descriptions.Item label='是否自由上麦'>
              {roomMicFree === 1 ? '是' : '否'}
            </Descriptions.Item>
            <Descriptions.Item label='心动值开关'>
              {roomScoreEnabled === 1 ? '开' : '关' }
            </Descriptions.Item>
            <Descriptions.Item label='公屏开关'>
              {roomChatEnabled === 1 ? '开' : '关' }
            </Descriptions.Item>

            <Descriptions.Item label='热门'>
              {hotEnable === 1 ? '已开启热门' : '已关闭热门'}
            </Descriptions.Item>
            <Descriptions.Item label='房间密码'>
              {roomLockPass}
            </Descriptions.Item>
          </Descriptions>
        </Card>
        <Card title='角色列表' style={_cardStyle}>
          <Table
            dataSource={roomRoleList}
            bordered
            pagination={false}
            rowKey={(record, i) => i}
          >
            <Column 
              title='用户名称'
              dataIndex='userName'
              key='userName'
            />
            <Column 
              title='用户角色'
              dataIndex='roomRoleName'
              key='roomRoleName'
            />
            
          </Table>
        </Card>
        <CRDetailCount 
          roomId={roomId}
        />
      </PageHeaderWrapper>
    )
  }
}
export default ChatRoomDetails
