/**
 * 
 * 聊天室分类
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Button, Modal, Icon, Menu, Tag, Pagination, Result } from 'antd'
import styles from './ChatRoomList.less'
// 引入接口
import { getRtcRoomPageList, updateRtcRoomStatus, getRtcCategoryPageList, setRoomHotEnable } from './api'
// 引入模块公用组件
import { ChatRoomsFilters, CreateChatRoom } from './components'
// 引入公用函数
import { getDate, showSuccess, showError } from '@/utils/base'
// 引入公用数据
import { getCategoryStatusStr } from './common'
import { SetSort } from '@/components/Modals'

class ChatRoomList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 处理状态
      handleStatus: undefined,
      // 分页
      pagination: {
        current: 1
      },
      businessType: 0
    }
  }
  componentDidMount() {
    this.getList()
    this.getRtcCategoryPageList()
  }

  // 新增
  onCreate = () => {
    CreateChatRoom({
      onOk: () => {
        showSuccess('房间创建成功')
        this.getList()
      }
    })
  }

  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const {
        handleStatus, startTime, endTime, pagination, itemName, categoryId, roomType,
        filterUserInfo, roomTitle, businessType
      } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20,
        businessType: businessType
      }
      // 名称
      if (itemName) {
        _params.roomName = itemName
      }
      // 标题
      if (roomTitle) {
        _params.roomTitle = roomTitle
      }
      // 用户
      if (filterUserInfo && filterUserInfo.userId) {
        _params.userId = filterUserInfo.userId
      }
      // 房间类型
      if ((roomType && roomType !== 'all') || roomType === 0) {
        _params.roomType = roomType
      }
      // 类目
      if (categoryId) {
        _params.categoryId = categoryId
      }
      // 配置状态
      if (handleStatus && handleStatus !== 'all') {
        _params.status = handleStatus
      }
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })

      const { data, code } = await getRtcRoomPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        list && list.map((item) => {
          item.statusStr = getCategoryStatusStr(item.categoryStatus)
          item.roomCreateTimeStr = item.roomCreateTime ? getDate(+item.roomCreateTime, 'yyyy.MM.dd') : '-'
        })
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  getRtcCategoryPageList = async () => {
    try {
      const { code, data } = await getRtcCategoryPageList({ pageNum: 1, pageSize: 200, status: 1 })
      if (code === 'OK' && data) {
        this.setState({
          categories: data.list
        })
      }
    } catch (e) {
      console.log(e)
    }
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (page, pageSize) => {
    const { pagination } = this.state
    pagination.current = page
    pagination.pageSize = pageSize
    this.setState({ pagination }, this.getList)
  }

  // 停启用
  onChangeStatus = ({ roomId, status }) => (e) => {
    e.preventDefault()
    const isStop = status === 1
    const msg = isStop ? '停用' : '启用'
    Modal.confirm({
      title: `${msg}提示`,
      content: `确定要执行${msg}操作么?`,
      okText: '确定',
      okType: 'primary',
      cancelText: '取消',
      onOk: () => {
        return updateRtcRoomStatus({ roomId, status: status === 1 ? 0 : 1 })
          .then(({ code }) => {
            if (code === 'OK') {
              showSuccess(msg + '操作执行成功')
              this.getList()
            }
          })
      }
    })
  }

  onChangeHostEnable = ({ roomId, hotEnable }) => (e) => {
    e.preventDefault()
    const isStop = hotEnable === 1
    const msg = isStop ? '关闭热门' : '开启热门'
    Modal.confirm({
      title: `${msg}提示`,
      content: `确定要执行${msg}操作么?`,
      okText: '确定',
      okType: 'primary',
      cancelText: '取消',
      onOk: () => {
        return setRoomHotEnable({ roomId, hotEnable: hotEnable === 1 ? 0 : 1 })
          .then(({ code }) => {
            if (code === 'OK') {
              showSuccess(msg + '操作执行成功')
              this.getList()
            }
          })
      }
    })
  }

  goDetails = ({ roomId }) => e => {
    e.preventDefault()
    router.push({
      pathname: '/chatRoom/roomList/roomDetails',
      query: {
        roomId
      }
    })
  }

  render() {
    const {
      loading, list, itemName, handleStatus, pagination, filterUserInfo, roomTitle,
      startTime, endTime, categories, categoryId, roomType, businessType
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total
    const isEmpty = !list || list.length === 0
    return (
      <PageHeaderWrapper
        title='聊天室列表'
        extra={
          <div>
            <Button
              onClick={this.onCreate}
              type='primary'
              icon='plus'
            >创建房间</Button>
          </div>
        }
      >
        <Card>
          <ChatRoomsFilters
            loading={loading}
            onChange={this.onChange}
            itemName={itemName}
            handleStatus={handleStatus}
            categories={categories}
            categoryId={categoryId}
            roomTitle={roomTitle}
            roomType={roomType}
            filterUserInfo={filterUserInfo}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
            businessType={businessType}
          />
          <div className={styles['rooms-wrap']}>
            {
              list && list.map((item) => (
                <Card
                  key={item.roomId}
                  className={styles['rooms-item']}
                  actions={[
                    <a href='#' onClick={this.goDetails(item)}>详情</a>,
                    // <a href='#' onClick={this.onChangeStatus(item)}>{item.status === 1 ? '停用' : '启用'}</a>,
                    // <a href='#' onClick={this.onChangeHostEnable(item)}>{item.hotEnable === 1 ? '关闭热门' : '开启热门'}</a>
                  ]}
                >
                  <div className={styles['room-bg']}>
                    <img src={item.roomCover} alt="" />
                  </div>
                  <div className={styles['room-content']}>
                    <div className={styles['room-item-top']}>
                      {
                        item.roomType === 101
                          ? <Tag color="#f50">相亲房</Tag>
                          : item.roomType === 201
                            ? <Tag color="#2db7f5">派发房</Tag>
                            : <Tag color="gray">普通房间</Tag>
                      }
                      {!!item.categoryName && <Tag color="gray">{item.categoryName}</Tag>}
                    </div>
                    <div className={styles['room-item-bot']}>
                      {item.status === 1 ? <Tag color="#87d068">已启用</Tag> : <Tag color="#f50">已停用</Tag>}
                      {item.hotEnable === 1 && <Tag color="#87d068" style={{ marginLeft: 6 }}>热门</Tag>}
                      <h3>{item.roomName}</h3>
                      <div>房间编号: {item.roomNo}</div>
                      <div>创建时间:{item.roomCreateTimeStr}</div>
                    </div>
                  </div>
                </Card>
              ))
            }
            {!loading && isEmpty && <Result title='空空如也' />}
          </div>
          <div className={styles['pagination-wrap']}>
            {!hidePagination && <Pagination {...pagination} onChange={this.onPageChange} />}
          </div>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default ChatRoomList
