/**
 * 
 * 房间流水
 */
import React, { Component } from 'react'
import styles from './ChatRoomflow.less'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Tabs, Table, Button, Tag, DatePicker } from 'antd'
import { SelectChatRoom } from '@/components/Modals'
import { MyDate, showError } from '@/utils/base'
import { getDayFilledList, getWeekFilledList, getMonthFilledList } from './common'
import {
  getRtcRoomDayStream, getRtcRoomWeekStream, getRtcRoomMonthStream,
} from './api'
import moment from 'moment'
import { AllRoomFlow } from './components'

const { TabPane } = Tabs
const { Column } = Table
const { RangePicker } = DatePicker
const _cardStyle = {
  marginBottom: 10
}

class ChatRoomflow extends Component {
  constructor(props) {
    super(props)
    const [startTime, endTime] = MyDate.getTimeDistance('month')
    this.state = {
      selectedChatRoom: {},
      currentTab: '1',
      startTime: startTime.valueOf(),
      endTime: endTime.valueOf(),
    }
  }
  onSelectChatRoom = () => {
    SelectChatRoom({
      onOk: (choosen) => {
        this.setState({
          selectedChatRoom: choosen[0]
        }, () => {
          const { currentTab } = this.state
          this.getFlowData(currentTab)
        })
      }
    })
  }
  onRoomClose = () => {
    this.setState({ selectedChatRoom: {}, dayList: [], weekList: [], monthList: [] })
  }

  getRtcRoomDayStream = async () => {
    const { selectedChatRoom, startTime, endTime } = this.state
    if (!selectedChatRoom || !selectedChatRoom.roomId) {
      return
    }

    const _state = {
      loading: false
    }

    try {
      const _params = {
        startTime, endTime, roomId: selectedChatRoom.roomId
      }
      this.setState({ loading: true })
      const { code, data } = await getRtcRoomDayStream(_params)
      if (code === 'OK') {
        // 获取填数组
        const filledList = getDayFilledList({ startTime, endTime })
        const { list, total } = data
        let listLen = list ? list.length : 0
        filledList.forEach((item) => {
          item.dateInfo = MyDate.getTimeFromLong(item.day)
          for (let i = 0; i < listLen; i++) {
            const subItem = list[i]
            // 如果日期相同 使用接口返回的数据
            if (item.day === (subItem.day + '')) {
              item.statValue = subItem.statValue
              break
            }
          }
        })

        _state.dayList = filledList
        _state.daySumValue = total
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }


  getRtcRoomWeekStream = async () => {
    const { selectedChatRoom } = this.state
    if (!selectedChatRoom || !selectedChatRoom.roomId) {
      return
    }
    const _state = {
      loading: false
    }
    try {
      this.setState({ loading: true })
      const { code, data } = await getRtcRoomWeekStream({ roomId: selectedChatRoom.roomId })
      if (code === 'OK' && data) {
        const { list } = data
        const filledArray = getWeekFilledList()
        let listLen = list ? list.length : 0
        filledArray.forEach((item) => {
          item.startDateInfo = MyDate.getTimeFromLong(item.startDate)
          item.endDateInfo = MyDate.getTimeFromLong(item.endDate)

          for (let i = 0; i < listLen; i++) {
            const subItem = list[i]
            if (item.weekOfYear === subItem.weekOfYear + 1) {
              item.statValue = subItem.statValue
              break
            }
          }
        })

        _state.weekList = filledArray
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  getRtcRoomMonthStream = async () => {
    const { selectedChatRoom } = this.state
    if (!selectedChatRoom || !selectedChatRoom.roomId) {
      return
    }
    const _state = {
      loading: false
    }
    try {
      this.setState({ loading: true })
      const { code, data } = await getRtcRoomMonthStream({ roomId: selectedChatRoom.roomId })
      if (code === 'OK' && data) {
        const { list } = data
        const filledArray = getMonthFilledList()
        const listLen = list ? list.length : 0
        filledArray.forEach((item) => {
          item.statMonthInfo = MyDate.getTimeFromLong(item.statMonth)
          item.startDateInfo = MyDate.getTimeFromLong(item.startDate)
          item.endDateInfo = MyDate.getTimeFromLong(item.endDate)
          for (let i = 0; i < listLen; i++) {
            const subItem = list[i]
            if (item.statMonth === subItem.statMonth) {
              item.statValue = subItem.statValue
              break
            }
          }
        })
        _state.monthList = filledArray
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  getFlowData = (activeKey) => {
    if (activeKey === '1') {
      this.getRtcRoomDayStream()
    } else if (activeKey === '2') {
      this.getRtcRoomWeekStream()
    } else if (activeKey === '3') {
      this.getRtcRoomMonthStream()
    }
  }

  onTabChange = (activeKey) => {
    this.getFlowData(activeKey)
    this.setState({ currentTab: activeKey })
  }

  // 日榜时间筛选
  onDailyTimeChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date').valueOf()
      _endTime = moments[1].endOf('date').valueOf()
    }

    const _90Days = 3600 * 24 * 90 * 1000
    if (_endTime - _startTime > _90Days) {
      showError('时间区间不能超过90天')
      return
    }
    this.setState({ startTime: _startTime, endTime: _endTime }, this.getRtcRoomDayStream)
  }

  render() {
    const {
      selectedChatRoom, currentTab, startTime, endTime,
      dayList, weekList, monthList
    } = this.state
    return (
      <PageHeaderWrapper>
        <Card style={_cardStyle}>
          <div className={styles['filter-wrap']}>
            {
              selectedChatRoom && selectedChatRoom.roomId
                ? <Tag
                  closable
                  onClose={this.onRoomClose}
                >{selectedChatRoom.roomName}</Tag>
                : <Button
                  onClick={this.onSelectChatRoom}
                  icon='plus'
                  type='primary'
                  ghost
                >选择房间</Button>
            }
          </div>

          <Tabs
            activeKey={currentTab}
            onChange={this.onTabChange}
          >
            <TabPane tab='日榜' key="1">
              <div className={styles['daily-filter-wrap']}>
                <RangePicker
                  value={[moment(startTime), moment(endTime)]}
                  onChange={this.onDailyTimeChange}
                />
              </div>
              <Table
                bordered
                dataSource={dayList}
                pagination={false}
                rowKey={(record, i) => i}
              >
                <Column
                  title='日期'
                  dataIndex='dateInfo'
                  key='dateInfo'
                  render={(text, { dateInfo }) => (
                    <div>{dateInfo.M}月{dateInfo.d}日</div>
                  )}
                />
                <Column
                  title='钻石'
                  dataIndex='statValue'
                  key='statValue'
                />
              </Table>
            </TabPane>
            <TabPane tab='周榜' key="2">
              <Table
                bordered
                dataSource={weekList}
                pagination={false}
                rowKey={(record, i) => i}
              >
                <Column
                  title='日期'
                  dataIndex='dateInfo'
                  key='dateInfo'
                  render={(text, { weekOfYear, startDateInfo, endDateInfo }) => (
                    <div>
                      <div>第{weekOfYear}周</div>
                      <p className={styles['item-time-gray']}>
                        {startDateInfo.M}/{startDateInfo.d}
                        -
                        {endDateInfo.M}/{endDateInfo.d}
                      </p>
                    </div>
                  )}
                />
                <Column
                  title='钻石'
                  dataIndex='statValue'
                  key='statValue'
                />
              </Table>
            </TabPane>
            <TabPane tab='月榜' key="3">
              <Table
                bordered
                dataSource={monthList}
                pagination={false}
                rowKey={(record, i) => i}
              >
                <Column
                  title='日期'
                  dataIndex='dateInfo'
                  key='dateInfo'
                  render={(text, { statMonthInfo, startDateInfo, endDateInfo }) => (
                    <div>
                      <div>{statMonthInfo.y}年{statMonthInfo.M}月</div>
                      <p className={styles['item-time-gray']}>
                        {startDateInfo.M}/{startDateInfo.d}
                        -
                        {endDateInfo.M}/{endDateInfo.d}
                      </p>
                    </div>
                  )}
                />
                <Column
                  title='钻石'
                  dataIndex='statValue'
                  key='statValue'
                />
              </Table>
            </TabPane>
          </Tabs>
        </Card>

        <AllRoomFlow />
      </PageHeaderWrapper>
    )
  }
}
export default ChatRoomflow
