import React, { Component } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Button, Card, Input, Select, DatePicker, Table } from 'antd';
import styles from './Radiohostflow.less';
import { showError } from '@/utils/base';
import moment from 'moment';
const Option = Select.Option;
const { RangePicker } = DatePicker;
const { Column } = Table;
export default class Radiohostflow extends Component {
  constructor(props) {
    super(props);
    const [startTime, endTime] = [moment().startOf('date'), moment().endOf('date')];
    this.state = {
      nickname: null,
      roomKey: null,
      startTime: startTime.valueOf(),
      endTime: endTime.valueOf(),
      tabList: [],
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
    }
  }

  //昵称选择
  onChangename = (e) => {
    this.setState({
      nickname: e.target.value
    });
  }
  //房间选择
  onSelectChange = (value) => {
    this.setState({ roomKey: value });
  }
  //翻页
  onTabpage = (page) => {
    console.log(page);
  }
  // 日榜时间筛选
  onDailyTimeChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }

    const _90Days = 3600 * 24 * 90 * 1000
    if (_endTime - _startTime > _90Days) {
      showError('时间区间不能超过90天')
      return
    }
    this.setState({ startTime: _startTime, endTime: _endTime })
  }
  render() {
    const { startTime, endTime, tabList, pagination } = this.state;
    return (
      <PageHeaderWrapper>
        <Card>
          <div className={styles.header_wrap}>
            <div><h4>主持：</h4><Input onChange={this.onChangename} style={{ width: 200 }} placeholder='昵称/id/称号' /></div>
            <div className={styles.box_margin}><h4>房间：</h4>
              <Select
                style={{ width: 200 }}
                placeholder='请选择房间'
                // allowClear
                defaultValue='all'
                onChange={this.onSelectChange}
              >
                <Option key='all'>全部</Option>
                <Option key='1'>1</Option>
                <Option key='2'>2</Option>
              </Select>
            </div>
            <div className={styles.box_margin}>
              <h4>时间：</h4>
              <RangePicker
                value={[moment(startTime), moment(endTime)]}
                onChange={this.onDailyTimeChange}
              />
            </div>
            <Button icon='search' className={styles.box_margin} type='primary'>查询</Button>
            <Button className={styles.box_margin}>导出</Button>
          </div>
          <Table
            bordered
            dataSource={tabList}
            pagination={pagination}
            style={{ marginTop: 30 }}
            onChange={this.onTabpage}
          >
            <Column
              title='日期'
              dataIndex='dateInfo'
              key='dateInfo'
              render={(text, { dateInfo }) => (
                <div>{dateInfo.M}月{dateInfo.d}日</div>
              )}
            />
            <Column
              title='钻石'
              dataIndex='statValue'
              key='statValue'
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
