import React, { Component } from 'react';
import { Card, DatePicker, Tabs, Table, Select } from 'antd';
import { getRtcRoomStream } from '../api';
import styles from './AllRoomFlow.less';
import moment from 'moment';
import { MyDate } from '@/utils/base';
import { getDayFilledList, getWeekFilledList, getMonthFilledList } from '../common';
import { getQueryString } from '@/utils/Url';

const TabPane = Tabs.TabPane;
const Column = Table.Column;
const Option = Select.Option;

const weekFilledList = getWeekFilledList();
const monthFilledList = getMonthFilledList();
monthFilledList.forEach(item => {
  item.statMonthInfo = MyDate.getTimeFromLong(item.statMonth);
  item.startDateInfo = MyDate.getTimeFromLong(item.startDate);
  item.endDateInfo = MyDate.getTimeFromLong(item.endDate);
});

class AllRoomFlow extends Component {
  constructor(props) {
    super(props);
    this.state = {
      currentTab: '1',
    };
  }

  getRtcRoomStream = async () => {
    const _state = { loading: false };
    try {
      const _params = {};
      const { currentTab, daily, startTime, endTime, monthStartTime, monthEndTime } = this.state;
      let listName = 'dailyList';
      // 日榜
      if (currentTab === '1') {
        if (!daily) {
          return;
        }
        _params.startTime = moment(daily).format('YYYYMMDD');
        _params.endTime = moment(daily).format('YYYYMMDD');
      }
      // 周榜
      if (currentTab === '2') {
        if (!startTime) {
          return;
        }
        _params.startTime = startTime;
        _params.endTime = endTime;
        listName = 'weekList';
      }
      // 月榜
      if (currentTab === '3') {
        if (!monthStartTime) {
          return;
        }
        _params.startTime = monthStartTime;
        _params.endTime = monthEndTime;
        listName = 'monthList';
      }
      this.setState({ loading: true });
      const { code, data } = await getRtcRoomStream(_params);
      if (code === 'OK' && data) {
        const { list } = data;
        _state[listName] = list;
      }
    } catch (e) {
      console.log(e);
    }
    this.setState(_state);
  };

  onTabChange = activeKey => {
    this.setState({ currentTab: activeKey });
  };
  onDailyTimeChange = dailyMoment => {
    this.setState(
      {
        daily: dailyMoment.valueOf(),
      },
      this.getRtcRoomStream,
    );
  };
  // 周
  onWeekListChange = key => {
    const item = weekFilledList[key];
    this.setState(
      {
        startTime: moment(item.startDate)
          .startOf('date')
          .format('YYYYMMDD'),
        endTime: moment(item.endDate)
          .endOf('date')
          .format('YYYYMMDD'),
      },
      this.getRtcRoomStream,
    );
  };

  //组件选择周
  handleWeek = (date, dateString) => {
    this.setState(
      {
        startTime: date.startOf('week').format('YYYYMMDD'),
        endTime: date.endOf('week').format('YYYYMMDD'),
      },
      this.getRtcRoomStream,
    );
  };
  // 月榜
  onMonthListChange = key => {
    const item = monthFilledList[key];
    this.setState(
      {
        monthStartTime: moment(item.startDate)
          .startOf('date')
          .format('YYYYMMDD'),
        monthEndTime: moment(item.endDate)
          .endOf('date')
          .format('YYYYMMDD'),
      },
      this.getRtcRoomStream,
    );
  };
  render() {
    const { currentTab, daily, monthList, weekList, dailyList, loading } = this.state;
    return (
      <Card title="全房间流水">
        <Tabs activeKey={currentTab} onChange={this.onTabChange}>
          <TabPane tab="日榜" key="1">
            <div className={styles['filter-wrap']}>
              <DatePicker
                onChange={this.onDailyTimeChange}
                value={daily ? moment(daily) : undefined}
                allowClear={false}
              />
            </div>
            <Table
              bordered
              dataSource={dailyList}
              pagination={false}
              rowKey={(record, i) => i}
              loading={loading}
            >
              <Column title="房间名称" dataIndex="roomName" key="roomName" />
              <Column title="星钻" dataIndex="statValue" key="statValue" />
            </Table>
          </TabPane>
          <TabPane tab="周榜" key="2">
            <div className={styles['filter-wrap']}>
              {getQueryString('dateType') === '2' ? (
                <Select placeholder="请选择周" onChange={this.onWeekListChange}>
                  {weekFilledList &&
                    weekFilledList.map((item, index) => (
                      <Option key={index}>
                        <div>
                          第{item.weekOfYear}周({item.startDate}~{item.endDate})
                        </div>
                      </Option>
                    ))}
                </Select>
              ) : (
                <DatePicker.WeekPicker placeholder="请选择周" onChange={this.handleWeek} />
              )}
            </div>
            <Table
              bordered
              dataSource={weekList}
              pagination={false}
              rowKey={(record, i) => i}
              loading={loading}
            >
              <Column title="房间名称" dataIndex="roomName" key="roomName" />
              <Column title="星钻" dataIndex="statValue" key="statValue" />
            </Table>
          </TabPane>
          <TabPane tab="月榜" key="3">
            <div className={styles['filter-wrap']}>
              <Select placeholder="请选择月" onChange={this.onMonthListChange}>
                {monthFilledList &&
                  monthFilledList.map((item, index) => (
                    <Option key={index}>
                      <div>
                        {item.statMonthInfo.y}年{item.statMonthInfo.M}月 ({item.startDateInfo.M}
                        {item.startDateInfo.d}~{item.endDateInfo.M}
                        {item.endDateInfo.d})
                      </div>
                    </Option>
                  ))}
              </Select>
            </div>
            <Table
              bordered
              dataSource={monthList}
              pagination={false}
              rowKey={(record, i) => i}
              loading={loading}
            >
              <Column title="房间名称" dataIndex="roomName" key="roomName" />
              <Column title="星钻" dataIndex="statValue" key="statValue" />
            </Table>
          </TabPane>
        </Tabs>
      </Card>
    );
  }
}
export default AllRoomFlow;
