import React, { Component } from 'react'
import { getRoomStat } from '../api'
import { Table, Card } from 'antd'
import { getCrStatTypeStr } from '@/utils/base'
const Column = Table.Column
class CRDetailCount extends Component {
  constructor (props) {
    super(props)
    this.state = {
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.getRoomStat()
  }
  getRoomStat = async () => {
    const _state = {
      loading: false
    }
    try {
      const { roomId } = this.props
      const { pagination } = this.state
      const _params = {
        pageIndex: pagination.current || 1, 
        pageSize: 20
      }
      if (!roomId) {
        return
      }
      _params.roomId = roomId
      this.setState({ loading: true })
      const { code, data } = await getRoomStat(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, pageSize, total } = data
        list && list.forEach((item) => {
          item.statTypeStr = getCrStatTypeStr(item.statType)
        })
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getRoomStat)
  }

  render () {
    const { pagination, list, loading } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total
    return (
      <Card title='统计列表'>
        <Table
          dataSource={list}
          pagination={hidePagination ? false : pagination}
          bordered
          rowKey={(record, i) => i}
          onChange={this.onPageChange}
          loading={loading}
        >
          <Column 
            title='统计类型'
            dataIndex='statTypeStr'
            key='statTypeStr'
          />
          <Column 
            title='统计值'
            dataIndex='statValue'
            key='statValue'
          />
          <Column 
            title='时间'
            dataIndex='statTime'
            key='statTime'
          />
        </Table>
      </Card>
    )
  }
} 
export default CRDetailCount
