/**
 * 
 * 筛选条件
 */
import React, { Component } from 'react'
import styles from './ChatRoomsFilters.less'
import { Select, Input, Button, DatePicker, InputNumber, Tag } from 'antd'
import moment from 'moment'
import { regIntNumber, chatRoomTypeArray } from '@/utils/base'
import { backgroundStatus } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class ChatRoomsFilters extends Component {
  onTagType = (key) => {
    const { onChange } = this.props
    onChange && onChange('tagType', key)
  }
  onInputChange = name => (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange(name, value)
  }
  // 状态改变
  onSelectChange = name => key => {
    const { onChange } = this.props
    onChange && onChange(name, key)
  }

  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render() {
    const {
      onSearch, itemName, roomTitle, handleStatus, roomType, startTime, endTime,
      filterUserInfo, categories, categoryId, loading, businessType
    } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>房间名:</h4>
          <Input
            placeholder='请输入房间名'
            style={_style}
            value={itemName}
            onChange={this.onInputChange('itemName')}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>房间标题:</h4>
          <Input
            placeholder='请输入房间标题'
            style={_style}
            value={roomTitle}
            onChange={this.onInputChange('roomTitle')}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>房间模块:</h4>
          <Select
            style={_style}
            placeholder='请选择房间模块'
            value={businessType}
            onChange={this.onSelectChange('businessType')}
            allowClear
          >
            <Option value={0} key={0}>语聊房</Option>
            <Option value={1} key={1}>直播房</Option>
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>类型:</h4>
          <Select
            style={_style}
            placeholder='请选择类型'
            value={roomType}
            onChange={this.onSelectChange('roomType')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              chatRoomTypeArray && chatRoomTypeArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>

        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>类目:</h4>
          <Select
            style={_style}
            placeholder='请选择类目'
            value={categoryId}
            onChange={this.onSelectChange('categoryId')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              categories && categories.map((item) => (
                <Option key={item.categoryId}>{item.categoryName}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>状态:</h4>
          <Select
            style={_style}
            placeholder='请选择状态'
            value={handleStatus}
            onChange={this.onSelectChange('handleStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              backgroundStatus && backgroundStatus.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div className={styles['btn-wrap']}>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
            loading={loading}
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default ChatRoomsFilters
