/**
 * 
 * 新建/编辑 聊天室房间
 */

// 引入react依赖
import React, { Component } from 'react'
// 引入antd组件
import { Drawer, Select, Radio, Button, Switch, Form, Input, InputNumber, Icon } from 'antd'
// 引入样式
import styles from './CreateChatRoom.less'
// 引入当前模块需要的接口函数
import { createRoom, getRtcCategoryPageList, getRtcRoomCoverUploadConfig } from '../../api'
import { chatRoomTypeArray } from '@/utils/base'
import MyUpload from '@/components/Custom/MyUpload'

// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}
const _itemStyle = {
  width: '100%'
}

// 下拉框
const Option = Select.Option

// 表单响应配置
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
}
// Form 
@Form.create()
class CreateChatRoom extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // loading
      loading: false,
    }
  }
  componentDidMount () {
    const { record } = this.props
    this.getRtcCategoryPageList()
  }

  getRtcCategoryPageList = async () => {
    const _state = {}
    try {
      const { code ,data } = await getRtcCategoryPageList({ 
        pageNum: 1, pageSize: 1000, status: 1})
      if (code === 'OK' && data) {
        _state.categories = data.list
      }
    } catch (e) {
      console.log(e)
    }
    
    this.setState(_state)
  }

  saveInstance = (_this) => {
    this.imageInstance = _this
  }


  onOk = () => {
    const { form, record } = this.props
    form.validateFieldsAndScroll((errors, values) => {
      if (errors) {
        return
      }
      const { 
        ...others 
      } = values
      const params = others
      const fileList = this.imageInstance.state.fileList
      if (!fileList || fileList.length === 0) {
        return
      }
      const first = fileList[0]
      params.roomCover = first.url
      this.onPost(params)
    })
  }

  // 上传数据
  onPost = async (params) => {
    let _code = ''
    try {
      this.setState({ uploading: true })
      const { code } = await createRoom(params)
      _code = code
    } catch (e) {
      console.log(e)
    }
    this.setState({ uploading: false })
    if (_code === 'OK') {
      const { onOk } = this.props 
      onOk && onOk()
    }
  }

  onLayoutImageClick = e => {
    e.stopPropagation()
  }

  getPopupContainer = () => {
    return this.containerNode || document.body
  }
  render () {
    const { onCancel, form, record } = this.props
    const { loading, uploading, categories  } = this.state
    const { getFieldDecorator } = form
    const isEdit = !!record
    return (
      <Drawer
        title={`${isEdit ? '编辑' : '新建'}房间`}
        onClose={onCancel}
        visible
        width={720}
      >
        <div className={styles['content-wrap']}>
          <div className={styles['content-body']} ref={node => this.containerNode = node }>
            <Form {...formItemLayout}>
              <Form.Item
                label='房间名称'
              >
                {getFieldDecorator('roomName', {
                  rules: [
                    { required: true, message: '请输入房间名称' },
                  ],
                })(
                  <Input
                    placeholder='请输入房间名称'
                    style={_itemStyle}
                  />
                )}
              </Form.Item>
              
              
              
              <Form.Item
                label='房间类型'
                required
              >
                {getFieldDecorator('roomType', {
                  rules: [
                    { required: true, message: '请选择房间类型' },
                  ],
                })(
                  <Select placeholder='请选择房间类型'>
                    {
                      chatRoomTypeArray && chatRoomTypeArray.map((item) => (
                        <Option key={item.key}>{item.value}</Option>
                      ))
                    }
                  </Select>
                )}
              </Form.Item>
              <Form.Item
                label='房间类目'
                required
              >
                {getFieldDecorator('categoryId', {
                  rules: [
                    { required: true, message: '请选择房间类目' },
                  ],
                })(
                  <Select placeholder='请选择房间类目'>
                    {
                      categories && categories.map((item) => (
                        <Option key={item.categoryId}>{item.categoryName}</Option>
                      ))
                    }
                  </Select>
                )}
              </Form.Item>
              
              <Form.Item
                label='房间封面图'
                required
              >
                <MyUpload
                  saveData={this.saveInstance}
                  requestFun={getRtcRoomCoverUploadConfig}
                />
              </Form.Item>
            </Form>
          </div>
          <div className={styles['footer-wrap']}>
            <Button 
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button 
              type='primary' 
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    )
  }
}
export default CreateChatRoom
