/**
 * 
 * 家族详情
 */

import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Button, Card, Descriptions, Table, DatePicker, Input } from 'antd'
import styles from './FamilyDetails.less'
import router from 'umi/router'
import { getFamilyDetail } from './api'
import ZImage from 'react-zmage'
import { getStatusStr } from './common'
import { getDate, showSuccess } from '@/utils/base'
import Decimal from 'decimal.js'

const _cardStyle = {
  marginBottom: 10
}

class FamilyDetails extends Component {
  constructor(props) {
    super(props)
    this.state = {
      familyId: props.location.query.familyId
    }
  }
  componentDidMount() {
    this.getDetails()
  }
  // 获取数据
  getDetails = async () => {
    const { familyId } = this.state
    const _state = {
      loading: false
    }

    try {
      this.setState({ loading: true })
      const { code, data } = await getFamilyDetail({ familyId })
      if (code === 'OK' && data) {

        const {
          familyName, familyLogo, familyNo, familyIntro, president, presidentName, status,
          createTime, presidentPhone, createUserName, userRatio, familyRatio, userSingleRtcRatio,
          familySingleRtcRatio
        } = data
        // 家族名称
        _state.familyName = familyName
        // 家族编号
        _state.familyNo = familyNo
        // 家族id
        _state.familyId = data.familyId
        // 家族简介
        _state.familyIntro = familyIntro
        // 家族分成比例
        _state.familyRatioReturn = familyRatio
        _state.familyRatio = (familyRatio || familyRatio === 0)
          ? new Decimal(familyRatio).mul(new Decimal(100)).toNumber()
          : undefined
        // 用户默认提成比例
        _state.userRatioReturn = userRatio
        _state.userRatio = (userRatio || userRatio === 0)
          ? new Decimal(userRatio).mul(new Decimal(100)).toNumber()
          : undefined
        //个播提成比例
        _state.userSingleRtcRatio = (userSingleRtcRatio || userSingleRtcRatio === 0)
          ? new Decimal(userSingleRtcRatio).mul(new Decimal(100)).toNumber()
          : undefined
        _state.familySingleRtcRatio = (familySingleRtcRatio || familySingleRtcRatio === 0)
          ? new Decimal(familySingleRtcRatio).mul(new Decimal(100)).toNumber()
          : undefined
        // 家族状态
        _state.status = status
        // 家族
        _state.familyLogo = familyLogo
        // 会长姓名
        _state.presidentName = presidentName
        // 会长id
        _state.president = president
        // 会长联系方式
        _state.presidentPhone = presidentPhone
        // 创建时间
        _state.createTime = createTime
        // 创建者
        _state.createUserName = createUserName
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  goDetails = () => {
    router.push({
      pathname: '/family/list/liveinfo'
    })
  }

  // 设置家族提成比例
  onEditFamilyRadio = () => {
    const { familyId, familyRatioReturn } = this.state
    // SetRadio({
    //   title: '设置家族提成比例',
    //   defaultParams: { familyId },
    //   ratioKey: 'familyRatio',
    //   requestFunc: updatefamilyRatio,
    //   ratio: familyRatioReturn,
    //   onOk: () => {
    //     showSuccess('家族提成比例设置成功')
    //     this.getDetails()
    //   }
    // })
  }
  // 设置主播默认提成比例
  onEditAnchorDefaultRadio = () => {
    const { familyId, anchorRatioReturn } = this.state
    // SetRadio({
    //   title: '设置主播默认提成比例',
    //   defaultParams: { familyId },
    //   ratioKey: 'anchorRatio',
    //   requestFunc: updateAnchorRatio,
    //   ratio: anchorRatioReturn,
    //   onOk: () => {
    //     showSuccess('主播默认提成比例设置成功')
    //     this.getDetails()
    //   }
    // })
  }

  render() {
    const {
      familyLogo, familyName, familyNo, familyId, status, createTime, presidentName,
      president, presidentPhone, createUserName, familyIntro, familyRatio, userRatio,
      userSingleRtcRatio, familySingleRtcRatio
    } = this.state
    return (
      <PageHeaderWrapper
        title='家族详情'
      >
        <Card style={_cardStyle} title='家族信息'>
          <Descriptions bordered>
            <Descriptions.Item label='家族头像'>
              <ZImage src={familyLogo} style={{ width: 80 }} />
            </Descriptions.Item>
            <Descriptions.Item label='家族名称' span={2}>
              {familyName}
            </Descriptions.Item>
            <Descriptions.Item label='家族ID'>
              {familyId}
            </Descriptions.Item>
            <Descriptions.Item label='家族编号'>
              {familyNo}
            </Descriptions.Item>
            <Descriptions.Item label='家族状态'>
              {getStatusStr(status)}
            </Descriptions.Item>
            <Descriptions.Item label='家族简介' span={3}>
              {familyIntro || '-'}
            </Descriptions.Item>

            <Descriptions.Item label='家族长昵称'>
              {presidentName}
            </Descriptions.Item>
            <Descriptions.Item label='家族长ID'>
              {president}
            </Descriptions.Item>
            <Descriptions.Item label='家族长联系方式'>
              {presidentPhone}
            </Descriptions.Item>
            <Descriptions.Item label='家族提成比例'>
              <div className={styles['editable-wrap']}>
                <span>{familyRatio || familyRatio === 0 ? `${familyRatio}%` : '-'}</span>
                <Button
                  icon='edit'
                  size='small'
                  type='primary'
                  ghost
                  onClick={this.onEditFamilyRadio}
                  hidden
                >编辑</Button>
              </div>
            </Descriptions.Item>
            <Descriptions.Item label='用户默认提成比例' span={2}>
              <div className={styles['editable-wrap']}>
                <span>{userRatio || userRatio === 0 ? `${userRatio}%` : '-'}</span>
                <Button
                  icon='edit'
                  size='small'
                  type='primary'
                  ghost
                  onClick={this.onEditAnchorDefaultRadio}
                  hidden
                >编辑</Button>
              </div>
            </Descriptions.Item>
            <Descriptions.Item label='个播家族提成比例'>
              <span>{familySingleRtcRatio || familySingleRtcRatio === 0 ? `${familySingleRtcRatio}%` : '-'}</span>
            </Descriptions.Item>
            <Descriptions.Item label='个播用户默认提成比例' span={2}>
              <span>{userSingleRtcRatio || userSingleRtcRatio === 0 ? `${userSingleRtcRatio}%` : '-'}</span>
            </Descriptions.Item>
            {/* <Descriptions.Item label='创建者'>
              {createUserName}
            </Descriptions.Item> */}
            <Descriptions.Item label='创建时间' span={3}>
              {createTime ? getDate(+createTime, 'yyyy-MM-dd hh:mm') : '-'}
            </Descriptions.Item>
          </Descriptions>
        </Card>

      </PageHeaderWrapper>
    )
  }
}
export default FamilyDetails
