/**
 * 
 * 签约列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Table } from 'antd'
import styles from './MemberAuditList.less'
import { getFamilyAuditPageList } from './api'
import { MemberAuditListFilters, AuditMember } from './components'
import { getDate, showSuccess } from '@/utils/base'
import ZImage from 'react-zmage'
import { getCommonAuditStatusStr, getApplyTypeStr } from './common'

const Column = Table.Column

class MemberAuditList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      list: [],
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount() {
    this.getList()
  }
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { auditStatus, userName, applyType, pagination } = this.state
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10
      }
      if (userName) {
        _params.userName = userName
      }
      if (auditStatus && auditStatus !== 'all') {
        _params.auditStatus = auditStatus
      }
      if (applyType && applyType !== 'all') {
        _params.applyType = applyType
      }

      this.setState({ loading: true })
      const { code, data } = await getFamilyAuditPageList(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, total, pageSize } = data
        list && list.forEach((item) => {
          item.auditStatusStr = getCommonAuditStatusStr(item.auditStatus)
          item.applyTypeStr = getApplyTypeStr(item.applyType)
        })
        _state.list = list
        // 页码信息
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 审核
  onAudit = record => e => {
    AuditMember({
      record,
      onOk: () => {
        showSuccess('审核成功')
        this.getList()
      }
    })
  }

  render() {
    const { list, loading, pagination, auditStatus, userName, applyType } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper>
        <Card>
          <MemberAuditListFilters
            onSearch={this.onSearch}
            onChange={this.onChange}
            auditStatus={auditStatus}
            applyType={applyType}
            userName={userName}
          />
          <Table
            dataSource={list}
            loading={loading}
            bordered
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            rowKey='auditId'
          >
            <Column
              title='名称'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='ID'
              key='userNo'
              dataIndex='userNo'
            />
            <Column
              title='头像'
              key='userAvatar'
              render={(text, { userAvatar }) => (
                userAvatar ? <ZImage src={userAvatar} style={{ width: 60 }} /> : '-'
              )}
            />
            <Column
              title='申请类型'
              key='applyTypeStr'
              dataIndex='applyTypeStr'
            />

            <Column
              title='申请说明'
              key='applyMsg'
              dataIndex='applyMsg'
              width='16%'
            />
            <Column
              title='是否强制'
              key='isForce'
              dataIndex='isForce'
              render={(isForce) => isForce === 1 ? '是' : '否'}
            />

            <Column
              title='审核状态'
              key='auditStatusStr'
              dataIndex='auditStatusStr'
              render={(text, { auditStatusStr, auditMsg }) => (
                <React.Fragment>
                  <div>{auditStatusStr}</div>
                  {!!auditMsg && <div>({auditMsg})</div>}
                </React.Fragment>
              )}
            />
            <Column
              title='申请时间'
              key='applyTime'
              render={(text, { applyTime }) => (
                getDate(+applyTime)
              )}
            />
            <Column
              title='审核时间'
              key='auditTime'
              render={(text, { auditTime }) => (
                auditTime === null ? '-' : getDate(+auditTime)
              )}
            />
            <Column
              title='操作人'
              key='adminName'
              dataIndex='adminName'
              render={(adminName) => (adminName || '-')}
            />

            <Column
              title='操作'
              key='actions'
              dataIndex='actions'
              render={(text, record) => (
                <div>
                  {
                    record.auditStatus === 0 && record.isForce != 1
                      ? <a onClick={this.onAudit(record)}>审核</a>
                      : '-'
                  }
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default MemberAuditList
