import React, { Component, Fragment } from 'react';
import styles from './Peoplemanagement.less';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Card, Table, Input, Button, Tag, Icon, Modal, notification, Divider } from 'antd';
// table 列组件
const Column = Table.Column;
import { getFamilyUserList, setTerminate } from './api.js';
import { getDate, showSuccess } from '@/utils/base'
// 引入的图片展示组件
import ZImage from 'react-zmage';
import router from 'umi/router';
const { TextArea } = Input;
export default class Peoplemanagement extends Component {
  constructor(props) {
    super(props);
    this.state = {
      pagination: {
        current: 1,
        pageSize: 10,
        total: 0
      },
      userName: null,
      list: [],
      loading: false,
      isTermination: false,
      rowKeys: [],
      visible: false,
      isSigle: false
    };
  }
  onInputChange = (e) => {
    this.setState({ userName: e.target.value });
  };
  onSearch = () => {
    this.getList();
  };
  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList);
  }
  //获取数据
  getList = async () => {
    let _state = {
      loading: false,
    };
    try {
      const { pagination, userName } = this.state;
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: pagination.pageSize
      }
      if (userName) {
        _params.userName = userName;
      }
      this.setState({ loading: true });
      const { code, data } = await getFamilyUserList(_params);
      const { pageIndex, total, pageSize } = data;
      if (code === 'OK' && data) {
        _state.list = data.list;
        _state.pagination = {
          current: pageIndex,
          pageSize: pageSize,
          total: total
        };
      }
    } catch (error) {
      console.log(error);
    }
    this.setState(_state);
  };
  componentDidMount() {
    this.getList();
  }
  //详情操作
  showDetails = (userId) => {
    router.push({
      pathname: '/family/management/details',
      query: {
        userId: userId
      }
    })
  }
  //确定解决按钮
  onSureTermination = () => {
    if (this.state.rowKeys.length > 0) {
      return this.setState({ visible: true, isSigle: false })
    }
    notification.open({
      message: '请选择解约主播',
      type: 'warning',
      duration: 2
    });

  }
  //选择解除成员
  onDeletePeople = (selectedRowKeys, deleteName) => {
    this.setState({
      rowKeys: selectedRowKeys,
      deleteName: deleteName
    });
  }
  //确认解除
  handleOk = async () => {
    const { content, rowKeys } = this.state;
    if (content) {
      let _params = {
        userIds: rowKeys.toString(),
        content: content
      }
      try {
        const result = await setTerminate(_params);
        if (result.code === 'OK' && result.success) {
          this.getList();
          return this.setState({ visible: false, isTermination: false, rowKeys: [], deleteName: '' })
        }
      } catch (error) {
        console.log(error);
      }
    }
    else {
      notification.open({
        message: '请填写解约原因',
        type: 'error',
        duration: 1
      });
    }
  }
  //单个解约按钮
  onTermination = (record) => {
    this.onDeletePeople([record.userId], record.userName);
    this.setState({ visible: true, isSigle: true });
  }
  render() {
    const { list, loading, pagination, isTermination, visible, rowKeys, deleteName, isSigle } = this.state;
    // 页码信息
    const { total, current, pageSize } = pagination;
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total;
    const rowSelection = {
      onChange: (selectedRowKeys, selectedRows) => {
        this.onDeletePeople(selectedRowKeys, selectedRows[0].userName);
      }
    };
    return (
      <PageHeaderWrapper
        title='家族成员管理'
      >
        <Card>
          <div className={styles.header_wrap}>
            <div className={styles.wrap}>
              <h4>用户名称:</h4>
              <Input
                placeholder='请输入用户名称'
                className={styles.inputLess}
                onChange={this.onInputChange}
                allowClear
              />
              <Button
                disabled={isTermination}
                onClick={this.onSearch}
                icon='search'
                type='primary'
              >搜索</Button>
            </div>
            <Fragment>
              {
                isTermination ? <div className={styles.button_wrap}>
                  <Button
                    onClick={() => this.setState({ isTermination: false, rowKeys: [], deleteName: '' })}
                    type='primary'
                  >取消</Button>
                  <Button
                    onClick={this.onSureTermination}
                    type='primary'
                  >确定</Button>
                </div> : <Button
                  onClick={() => this.setState({ isTermination: true })}
                  type='primary'
                >解约成员</Button>
              }
            </Fragment>
          </div>
          <Table
            dataSource={list}
            loading={loading}
            bordered
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            rowKey='userId'
            rowSelection={isTermination ? rowSelection : null}
          >
            <Column
              title='头像'
              key='userAvatar'
              dataIndex='userAvatar'
              render={(text, { userAvatar }) => (
                userAvatar
                  ? <ZImage src={userAvatar} style={{ width: 60 }} />
                  : '-'
              )}
            />
            <Column
              title='ID'
              key='userNo'
              dataIndex='userNo'
              render={(userNo, record) => (
                <div>
                  <div>{userNo}</div>
                  {record.userIsRobot === 1 && <Tag color="magenta">机器人</Tag>}
                </div>
              )}
            />
            <Column
              title='昵称'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='性别'
              key='userSex'
              dataIndex='userSex'
              render={userSex => (
                userSex === 1
                  ? <Icon type="man" style={{ color: '#1890ff' }} />
                  : userSex === 2
                    ? <Icon type="woman" style={{ color: '#eb2f96' }} />
                    : '-'
              )}
            />
            <Column
              title='手机号'
              key='userPhone'
              dataIndex='userPhone'
              render={text => text || '-'}
            />
            <Column
              title='财富等级'
              key='wealthLevel'
              dataIndex='wealthLevel'
              sorter={(a, b) => a.wealthLevel - b.wealthLevel}
            />
            <Column
              title='星耀等级'
              key='starLevel'
              dataIndex='starLevel'
              sorter={(a, b) => a.starLevel - b.starLevel}
            />
            <Column
              title='注册时间'
              key='signTime'
              dataIndex='signTime'
              sorter={(a, b) => a.signTime - b.signTime}
              render={(text, { signTime }) => (
                <div>
                  {signTime && signTime !== '0'
                    ? getDate(+signTime, 'yyyy-MM-dd hh:mm')
                    : '-'
                  }
                </div>
              )}
            />
            <Column
              title='操作'
              key='userId'
              dataIndex='userId'
              render={(text, record) => (
                <Fragment>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.showDetails(record.userId);
                  }}>详情</a>
                  <Divider type='vertical' />
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.onTermination(record);
                  }}>解约</a>
                </Fragment>
              )}
            />
          </Table>
        </Card>
        <Modal
          title={
            <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'flex-end' }}>
              <div>解约确认</div>
              <div style={{ fontSize: 10 }}>
                将和{rowKeys.length > 1 ? `${rowKeys.length}位主播` : deleteName}解约
              </div>
            </div>
          }
          visible={visible}
          onOk={this.handleOk}
          onCancel={() => isSigle ?
            this.setState({ visible: false, rowKeys: [], deleteName: '' }) :
            this.setState({ visible: false })}
          destroyOnClose
          closable={false}
        >
          <TextArea
            placeholder='请填写解约原因，解约后将不再和本家族有关系，必填'
            onChange={(e) => this.setState({ content: e.target.value.trim() })} rows={4} />
        </Modal>
      </PageHeaderWrapper>
    )
  }
}
