/**
 * 
 * 技能认证列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Table, Modal } from 'antd'
import styles from './SkillAuditList.less'
import { getFamilySkillAuditPageList } from './api'
import { SkillAuditListFilters, AuditSkill, RemoveSkill } from './components'
import { getDate, showSuccess } from '@/utils/base'
import { getCommonAuditStatusStr } from './common'
import ZImage from 'react-zmage'

const Column = Table.Column

class SkillAuditList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      list: [],
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount() {
    this.getList()
  }
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { auditStatus, pagination } = this.state
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10
      }
      if (auditStatus && auditStatus !== 'all') {
        _params.auditStatus = auditStatus
      }
      this.setState({ loading: true })
      const { code, data } = await getFamilySkillAuditPageList(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, total, pageSize } = data
        list && list.forEach((item) => {
          item.auditStatusStr = getCommonAuditStatusStr(item.auditStatus)
        })
        _state.list = list
        // 页码信息
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 审核
  onAudit = record => e => {
    AuditSkill({
      record,
      onOk: this.getList
    })
  }
  // 移除技能 
  onRemoveSkill = record => e => {
    RemoveSkill({
      record: record,
      onOk: () => {
        showSuccess('移除操作执行成功')
        this.getList()
      }
    })
  }

  render() {
    const { list, loading, pagination, auditStatus } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper>
        <Card>
          <SkillAuditListFilters
            onSearch={this.onSearch}
            onChange={this.onChange}
            auditStatus={auditStatus}
          />
          <Table
            dataSource={list}
            loading={loading}
            bordered
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            rowKey='auditId'
          >
            <Column
              title='技能名称'
              key='skillName'
              dataIndex='skillName'
            />
            <Column
              title='技能标签'
              key='skillTagName'
              dataIndex='skillTagName'
            />

            <Column
              title='技能描述'
              key='skillIntro'
              dataIndex='skillIntro'
              width='14%'
            />
            <Column
              title='图片'
              key='images'
              dataIndex='images'
              render={(images) => (
                images
                  ? <ZImage src={images} style={{ width: 60 }} />
                  : '-'
              )}
            />
            <Column
              title='声音'
              key='voice'
              dataIndex='voice'
              render={(voice) => (
                voice
                  ? <audio src={voice} preload="metadata" controls />
                  : '-'
              )}
            />
            <Column
              title='用户名称'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='审核状态'
              key='auditStatusStr'
              dataIndex='auditStatusStr'
              render={(text, { auditStatusStr, auditMsg }) => (
                <React.Fragment>
                  <div>{auditStatusStr}</div>
                  {!!auditMsg && <div>({auditMsg})</div>}
                </React.Fragment>
              )}
            />
            <Column
              title='申请时间'
              key='createTime'
              dataIndex='createTime'
              render={(text, { createTime }) => (
                getDate(+createTime)
              )}
            />
            <Column
              title='审核时间'
              key='auditTime'
              dataIndex='auditTime'
              render={(text, { auditTime }) => (
                getDate(+auditTime)
              )}
            />
            <Column
              title='操作'
              key='actions'
              dataIndex='actions'
              render={(text, record) => (
                <div>
                  {
                    record.auditStatus === 0
                      ? <a onClick={this.onAudit(record)}>审核</a>
                      : record.auditStatus === 1
                        ? <a onClick={this.onRemoveSkill(record)}>移除</a>
                        : '-'
                  }
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default SkillAuditList
