/**
 * 
 * 技能订单 列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Button, Modal, Dropdown, Menu }  from 'antd' 
import styles from './SkillOrderList.less'
// 引入接口
import { getSkillOrderPageList } from './api'
// 引入模块公用组件
import { SkillOrderFilters } from './components'
// 引入公用函数
import { getDate, showSuccess, getSkillUnitStr } from '@/utils/base'
// 引入模块公用函数
import { getOrderStatusStr, getOrderPayStatusStr } from './common'
// 引入的图片展示组件
import ZImage from 'react-zmage'

// table 
const Column = Table.Column
const fmt = 'yyyy.MM.dd hh:mm'

class SkillOrderList extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 处理状态
      status: undefined,
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.getList()
  }
  
  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { orderStatus, payStatus, startTime, endTime, pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10
      }
     
      // 订单状态
      if (orderStatus && orderStatus !== 'all') {
        _params.orderStatus = orderStatus
      }
      // 支付状态
      if (payStatus && payStatus !== 'all') {
        _params.payStatus = payStatus
      }
      
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getSkillOrderPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        list && list.forEach((item) => {
          item.orderStatusStr = getOrderStatusStr(item.orderStatus)
          item.payStatusStr = getOrderPayStatusStr(item.payStatus)
          item.unitStr = getSkillUnitStr(item.unit)
          item.updateTimeStr = getDate(+item.updateTime, fmt)
          item.createTimeStr = getDate(+item.createTime, fmt)
          item.payTimeStr = item.payTime ? getDate(+item.payTime, fmt) : '-'
          item.requireTimeStr = item.requireTime ? getDate(+item.requireTime, fmt) : '-'
          item.handleTimeStr = item.handleTime ? getDate(+item.handleTime, fmt) : '-'
          item.startTimeStr = item.startTime ? getDate(+item.startTime, fmt) : '-'
          item.endTimeStr = item.endTime ? getDate(+item.endTime, fmt) : '-'
          item.cancelTimeStr = item.cancelTime ? getDate(+item.cancelTime, fmt) : '-'
        })
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  render () {
    const { 
      loading, list, orderStatus, skillType, payStatus, pagination,
      startTime, endTime
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize > total
    return (
      <PageHeaderWrapper 
        title='技能订单列表'
      >
        <Card>
          <SkillOrderFilters 
            onChange={this.onChange}
            orderStatus={orderStatus}
            payStatus={payStatus}
            onSearch={this.onSearch}
            skillType={skillType}
            startTime={startTime}
            endTime={endTime}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='orderId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
          >
            <Column 
              title='下单用户'
              key='userName'
              dataIndex='userName'
              render={(text, { userName, userAvatar }) => (
                <div>
                  <div>名称：{userName} </div>
                  <div>头像：<ZImage src={userAvatar} style={{width: 30}} /></div>
                </div>
              )}
            />
            <Column 
              title='接单单价(数量)'
              key='orderPrice'
              dataIndex='orderPrice'
              render={(text, { orderPrice, unitStr, quantity }) => (
                <div>{orderPrice}{unitStr}({quantity})</div>
              )}
            />
            <Column 
              title='支付金额'
              key='payAmount'
              dataIndex='payAmount'
            />
            <Column 
              title='支付状态'
              key='payStatusStr'
              dataIndex='payStatusStr'
            />
            <Column 
              title='订单状态'
              key='orderStatusStr'
              dataIndex='orderStatusStr'
            />
            <Column 
              title='技能信息'
              key='skillName'
              dataIndex='skillName'
              render={(text, { skillName, skillTagName }) => (
                <div>
                  <div>名称：{skillName}</div>
                  <div>标签：{skillTagName}</div>
                </div>
              )}
            />
            <Column 
              title='接单人'
              key='receiveUserName'
              dataIndex='receiveUserName'
            />
            <Column 
              title='接单家族'
              key='receiveFamilyName'
              dataIndex='receiveFamilyName'
            />
            <Column 
              title='备注'
              key='remark'
              dataIndex='remark'
              width='14%'
              render={(remark) => (remark || '-')}
            />
             
            <Column 
              title='时间'
              key='updateTime'
              dataIndex='updateTime'
              render={(text, { 
                createTimeStr, payTimeStr, requireTimeStr,
                handleTimeStr, startTimeStr, endTimeStr
              }) => (
                <div>
                  <div>创建时间: {createTimeStr}</div>
                  <div>支付时间: {payTimeStr}</div>
                  <div>要求时间: {requireTimeStr}</div>
                  <div>处理时间: {handleTimeStr}</div>
                  <div>服务开始: {startTimeStr}</div>
                  <div>服务结束: {endTimeStr}</div>
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default SkillOrderList
