import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Card, Button, Descriptions, Icon, Table } from 'antd';
import router from 'umi/router';
import { getFamilyUserDetail, getFamilyAuditPageList, getFamilySkillAuditPageList } from './api.js';
import ZImage from 'react-zmage';
import { getDate, showSuccess } from '@/utils/base';
import { AuditSkill, RemoveSkill } from './components'
const Column = Table.Column;

export default class Userdetail extends Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      userId: props.location.query.userId,
      informationObj: {},
      signPagination: {
        current: 1,
        pageSize: 10,
        total: 0
      },
      skillPagination: {
        current: 1,
        pageSize: 10,
        total: 0
      },
      signOrderList: [],
      skillOrederList: []
    }
  }
  //获取用户详情
  getUserinformation = async () => {
    try {
      const informationObj = await getFamilyUserDetail({ userId: this.state.userId });
      const { code, data } = informationObj;
      if (code == 'OK' && data) {
        this.setState({ informationObj: data, loading: false });
      }
    } catch (error) {
      console.log(error);
    }
  };
  //获取签约记录
  getSignOrderlist = async () => {
    const { userId, signPagination } = this.state;
    try {
      const _params = {
        userId: userId,
        pageIndex: signPagination.current || 1,
        pageSize: signPagination.pageSize
      };
      const signList = await getFamilyAuditPageList(_params);
      const { code, data } = signList;
      if (code == 'OK' && data) {
        const { pageIndex, total, pageSize, list } = data;
        let signPagination = {
          current: pageIndex,
          pageSize: pageSize,
          total: total
        }
        this.setState({ loading: false, signPagination, signOrderList: list });
      }
    } catch (error) {
      console.log(error);
    }
  }
  onPageChange = (signPagination) => {
    this.setState({ signPagination }, this.getSignOrderlist);
  }
  onSkillPageChange = (skillPagination) => {
    this.setState({ skillPagination }, this.getSkillOrderlist);
  }
  //获取技能认证记录
  getSkillOrderlist = async () => {
    const { userId, skillPagination } = this.state;
    try {
      const _params = {
        userId: userId,
        pageIndex: skillPagination.current || 1,
        pageSize: skillPagination.pageSize
      };
      const skillList = await getFamilySkillAuditPageList(_params);
      const { code, data } = skillList;
      if (code == 'OK' && data) {
        const { pageIndex, total, pageSize, list } = data;
        let skillPagination = {
          current: pageIndex,
          pageSize: pageSize,
          total: total
        }
        this.setState({ loading: false, skillPagination, skillOrederList: list });
      }
    } catch (error) {

    }
  }
  // 审核
  onAudit = record => e => {
    AuditSkill({
      record,
      onOk: this.getSkillOrderlist
    });
  }
  // 移除技能 
  onRemoveSkill = record => e => {
    RemoveSkill({
      record: record,
      onOk: () => {
        showSuccess('移除操作执行成功')
        this.getSkillOrderlist()
      }
    })
  }
  componentDidMount() {
    this.setState({ loading: true });
    this.getUserinformation();
    this.getSignOrderlist();
    this.getSkillOrderlist();
  }
  render() {
    const { loading, informationObj, signOrderList, signPagination, skillPagination, skillOrederList } = this.state;
    const { userAvatar, userName,
      userSex, userNo,
      userPhone, wealthLevel,
      starLevel, signTime
    } = informationObj;
    // 石否隐藏 分页信息
    //签约记录
    const signHidePagination = signPagination.current === 1 && signPagination.pageSize >= signPagination.total;
    //技能认证记录
    const skilHidePagination = skillPagination.current === 1 && skillPagination.pageSize >= skillPagination.total;

    return (
      <PageHeaderWrapper
        title='成员详情'
        extra={
          <div>
            <Button
              onClick={router.goBack}
              type='default'
              icon='left'
            >返回</Button>
          </div>
        }>
        <Card title='基本信息' loading={loading}>
          <Descriptions bordered>
            <Descriptions.Item label='头像'>
              {userAvatar ? <ZImage src={userAvatar} style={{ width: 80 }} /> : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='昵称'>
              {userName}
            </Descriptions.Item>
            <Descriptions.Item label='ID'>
              {userNo}
            </Descriptions.Item>
            <Descriptions.Item label='性别'>
              {
                userSex === 1
                  ? <Icon type="man" style={{ color: '#1890ff' }} />
                  : userSex === 2
                    ? <Icon type="woman" style={{ color: '#eb2f96' }} />
                    : '-'
              }
            </Descriptions.Item>
            <Descriptions.Item label='手机号'>
              {userPhone || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='财富等级'>
              {wealthLevel}
            </Descriptions.Item>
            <Descriptions.Item label='星耀等级'>
              {starLevel}
            </Descriptions.Item>
            <Descriptions.Item label='签约时间'>
              {signTime && signTime !== '0'
                ? getDate(+signTime, 'yyyy-MM-dd hh:mm')
                : '-'
              }
            </Descriptions.Item>
          </Descriptions>
        </Card>
        <Card title='签约记录' loading={loading} style={{ marginTop: '20px' }}>
          <Table
            dataSource={signOrderList}
            loading={loading}
            bordered
            pagination={signHidePagination ? false : signPagination}
            onChange={this.onPageChange}
            rowKey='auditId'
          >
            <Column
              title='申请说明'
              key='applyMsg'
              dataIndex='applyMsg'
              width='16%'
            />
            <Column
              title='是否强制'
              key='isForce'
              dataIndex='isForce'
              render={(isForce) => isForce === 1 ? '是' : '否'}
            />

            <Column
              title='审核状态'
              key='auditStatusStr'
              dataIndex='auditStatusStr'
              render={(text, { auditStatusStr, auditMsg }) => (
                <React.Fragment>
                  <div>{auditStatusStr}</div>
                  {!!auditMsg && <div>({auditMsg})</div>}
                </React.Fragment>
              )}
            />
            <Column
              title='申请时间'
              key='applyTime'
              render={(text, { applyTime }) => (
                getDate(+applyTime)
              )}
            />
            <Column
              title='审核时间'
              key='auditTime'
              render={(text, { auditTime }) => (
                getDate(+auditTime)
              )}
            />
          </Table>
        </Card>
        <Card title='技能认证记录' loading={loading} style={{ marginTop: '20px' }}>
          <Table
            dataSource={skillOrederList}
            loading={loading}
            bordered
            pagination={skilHidePagination ? false : skillPagination}
            onChange={this.onSkillPageChange}
            rowKey='auditId'
          >
            <Column
              title='技能名称'
              key='skillName'
              dataIndex='skillName'
            />
            <Column
              title='技能标签'
              key='skillTagName'
              dataIndex='skillTagName'
            />

            <Column
              title='技能描述'
              key='skillIntro'
              dataIndex='skillIntro'
              width='14%'
            />
            <Column
              title='图片'
              key='images'
              dataIndex='images'
              render={(images) => (
                images
                  ? <ZImage src={images} style={{ width: 60 }} />
                  : '-'
              )}
            />
            <Column
              title='声音'
              key='voice'
              dataIndex='voice'
              render={(voice) => (
                voice
                  ? <audio src={voice} preload="metadata" controls />
                  : '-'
              )}
            />
            <Column
              title='用户名称'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='审核状态'
              key='auditStatusStr'
              dataIndex='auditStatusStr'
              render={(text, { auditStatusStr, auditMsg }) => (
                <React.Fragment>
                  <div>{auditStatusStr}</div>
                  {!!auditMsg && <div>({auditMsg})</div>}
                </React.Fragment>
              )}
            />
            <Column
              title='申请时间'
              key='createTime'
              dataIndex='createTime'
              render={(text, { createTime }) => (
                getDate(+createTime)
              )}
            />
            <Column
              title='审核时间'
              key='auditTime'
              dataIndex='auditTime'
              render={(text, { auditTime }) => (
                getDate(+auditTime)
              )}
            />
            <Column
              title='操作人'
              key='adminName'
              dataIndex='adminName'
            />
            <Column
              title='操作'
              key='actions'
              dataIndex='actions'
              render={(text, record) => (
                <div>
                  {
                    record.auditStatus === 0
                      ? <a onClick={this.onAudit(record)}>审核</a>
                      : record.auditStatus === 1
                        ? <a onClick={this.onRemoveSkill(record)}>移除</a>
                        : '-'
                  }
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
