/**
 * 
 * 单聊匹配
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Table } from 'antd'
import styles from './VoiceChatList.less'
// 引入接口
import { getVoiceChatPageList } from './api'
// 引入模块公用组件
import { VoiceChatListFilters } from './components'
// 引入公用函数
import { getDate, getWalletType } from '@/utils/base'
// 引入模块公用函数
import Decimal from 'decimal.js'
import { getVoiceChatStatusStr, getVoiceChatStopReasonStr } from './common'

// table 列组件
const Column = Table.Column

// 列表组件
class VoiceChatList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 处理状态
      handleStatus: undefined,
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount() {
    this.getList()
  }

  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { handleStatus, startTime, endTime, pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20
      }

      // 状态
      if (handleStatus && handleStatus !== 'all') {
        _params.hisStatus = handleStatus
      }

      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getVoiceChatPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        // 列表数据
        list && list.map((item) => {
          item.hisStatusStr = getVoiceChatStatusStr(item.hisStatus)
          item.hisUpdateTimeStr = item.hisUpdateTime ? getDate(+item.hisUpdateTime) : '-'
          item.hisCreateTimeStr = item.hisCreateTime ? getDate(+item.hisCreateTime) : '-'
          item.hisCancelTimeStr = item.hisCancelTime ? getDate(+item.hisCancelTime) : '-'
          item.matchStartTimeStr = item.matchStartTime ? getDate(+item.matchStartTime) : '-'
          item.matchEndTimeStr = item.matchEndTime ? getDate(+item.matchEndTime) : '-'
          item.hisStartTimeStr = item.hisStartTime ? getDate(+item.hisStartTime) : '-'
          item.hisStopTimeStr = item.hisStopTime ? getDate(+item.hisStopTime) : '-'
          item.hisPriceTypeStr = getWalletType(item.hisPriceType)
          item.stopReasonStr = getVoiceChatStopReasonStr(item.stopReason)
        })
        _state.list = list
        // 页码信息
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 计算价格
  calculateMoney = (hisPrice, hisMinutes) => {
    // Decimal
    if (!hisMinutes || !hisPrice) {
      return 0
    }
    return new Decimal(hisPrice).mul(new Decimal(hisMinutes)).toNumber()
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  render() {
    const {
      loading, list, targetUserName, userName, handleStatus, pagination,
      startTime, endTime, isRobot
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        title='语音速配'
      >
        <Card>
          <VoiceChatListFilters
            onChange={this.onChange}
            userName={userName}
            handleStatus={handleStatus}
            targetUserName={targetUserName}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
            isRobot={isRobot}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='hisId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
            className='table-wrap'
          >
            <Column
              title='发起人姓名'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='接收人名称'
              key='targetUserName'
              dataIndex='targetUserName'
            />
            <Column
              title='单价(钻石/分)'
              key='hisPrice'
              dataIndex='hisPrice'
              render={(text, { hisPrice, hisPriceTypeStr }) => (
                <div>{hisPrice}({hisPriceTypeStr})</div>
              )}
            />
            <Column
              title='计费分钟数'
              key='hisMinutes'
              dataIndex='hisMinutes'
              render={(text, { hisMinutes, hisCoinMinutes, hisTimeMinutes }) => (
                <div>
                  <div>总分钟数: {hisMinutes}</div>
                  <div>金币计费分钟数: {hisCoinMinutes}</div>
                  <div>时间钱包分钟数: {hisTimeMinutes}</div>
                </div>
              )}
            />

            <Column
              title='是否匹配模式'
              key='hisIsMatch'
              dataIndex='hisIsMatch'
              render={(text, { hisIsMatch }) => (
                <div>
                  {hisIsMatch === 1 ? '是' : '否'}
                </div>
              )}
            />
            <Column
              title='语聊时间'
              key='matchStartTime'
              dataIndex='matchStartTime'
              render={(text, { matchStartTimeStr, matchEndTimeStr, hisStartTimeStr, hisStopTimeStr }) => (
                <div style={{ whiteSpace: 'nowrap' }}>
                  <div>匹配开始：{matchStartTimeStr}</div>
                  <div>匹配结束：{matchEndTimeStr}</div>
                  <div>开始时间：{hisStartTimeStr}</div>
                  <div>结束时间：{hisStopTimeStr}</div>
                </div>
              )}
            />
            <Column
              title='记录时间'
              key='matchTimeStr'
              dataIndex='matchTimeStr'
              render={(text, { hisUpdateTimeStr, hisCreateTimeStr, hisCancelTimeStr }) => (
                <div style={{ whiteSpace: 'nowrap' }}>
                  <div>创建时间：{hisCreateTimeStr}</div>
                  <div>更新时间：{hisUpdateTimeStr}</div>
                  <div>取消时间：{hisCancelTimeStr}</div>
                </div>
              )}
            />
            <Column
              title='状态'
              key='hisStatus'
              dataIndex='hisStatus'
              render={(text, { hisStatusStr }) => (
                <div>{hisStatusStr}</div>
              )}
            />
            <Column
              title='停止原因'
              key='stopReasonStr'
              dataIndex='stopReasonStr'
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default VoiceChatList
