/**
 * 
 * 选择会长
 */
import React, { Component } from 'react'
import { Drawer, Select, Table, Button, Radio } from 'antd'
import styles from './SelectMaster.less'
import { getDate, showError } from '@/utils/base'
import { getReportPageList } from '../../api'

const Option = Select.Option
const Column = Table.Column
const _style = {
  width: '100%'
}
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}
class SelectMaster extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 分页
      pagination: {
        current: 1
      },
      list: [],
      selectedRow: {}
    }
  }
  componentDidMount () {
    const { selectedRows } = this.props
    const _state = {}
    if (selectedRows) {
      _state.selectedRows = selectedRows
      _state.selectedRowKeys = selectedRows.map(item => item.hisId)
    }
    this.setState(_state)
    this.getList()
  }

  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { userName, pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageNum: pagination.current || 1,
        pageSize: 10
      }
      // 名字
      if (userName) {
        _params.userName = userName
      }

      this.setState({ loading: true })
      const { data, code } = await getReportPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  onSelect = (selectedRows = []) => {
    let selectedRowKeys = selectedRows.map(item => item.reportId)
    this.setState({ selectedRows, selectedRowKeys })
  }

  onPageChange = () => {
    this.getList()
  }

  onRowClick = (record) => {
    
    return {
      onClick: () => {
        this.state.selectedRow.checked = false
        record.checked = true
        this.setState({ selectedRow: record })
      }
    }
  }
  
  onOk = () => {
    const { selectedRow } = this.state
    const { onOk } = this.props
    
    onOk && onOk(selectedRow)
  }
  render () {
    const { onCancel } = this.props
    const { selectedRowKeys, loading, list, pagination } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize > total
    const rowSelection = {
      selectedRowKeys,
      onSelect: (record, selected, selectedRows) => {
        this.onSelect(selectedRows)
      },
      onSelectAll: (selected, selectedRows, changeRows) => {
        this.onSelect(selectedRows)
      },
    }
    
    return (
      <Drawer
        title='选择会长(单选)'
        onClose={onCancel}
        visible
        width={1020}
      >
        <div className={styles['content-wrap']}>
          <Table
            loading={loading}
            dataSource={list}
            rowKey='reportId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
            onRow={this.onRowClick}
          >
            <Column 
              title='单选'
              key='radio'
              dataIndex='radio'
              width={80}
              align='center'
              render={(text, record) => (<Radio checked={!!record.checked}/>)}
            />
            <Column 
              title='昵称'
              key='userName'
              dataIndex='userName'
            />
            <Column 
              title='ID'
              key='userNo'
              dataIndex='userNo'
            />
            <Column 
              title='地区'
              key='areaName'
              dataIndex='areaName'
              render={(text, { areaName }) => (
                <div>
                  {areaName}
                </div>
              )}
            />
            <Column 
              title='主播等级'
              key='charmLevel'
              dataIndex='charmLevel'
            />
            <Column 
              title='开播时间'
              key='liveStartTime'
              dataIndex='liveStartTime'
              render={(text, { liveStartTime }) => (
              <div>{liveStartTime ? getDate(+liveStartTime, 'yyyy-MM-dd hh:mm') : '-'}</div>
              )}
            />
            
            <Column 
              title='热度'
              key='liveHeat'
              dataIndex='liveHeat'
            />
          </Table>
          <div className={styles['footer-wrap']}>
            <Button 
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button 
              type='primary' 
              style={_btnStyle}
              onClick={this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    )
  }
}
export default SelectMaster
