/**
 * 
 * 技能认证列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './SkillAuditListFilters.less'
import { Select, Input, Button, DatePicker } from 'antd'
import moment from 'moment'
import { commonAuditStatus } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onSelectChange = name => key => {
    const { onChange } = this.props
    onChange && onChange(name, key)
  }
  onInputChange = name => e => {
    const { onChange } = this.props
    onChange && onChange(name, e.target.value)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { onSearch, auditStatus, familyName, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']} hidden>
          <h4 className={styles['filter-label']}>家族名称:</h4>
          <Input 
            placeholder='请输入家族名称'
            style={_style}
            value={familyName}
            onChange={this.onInputChange('familyName')}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>认证状态:</h4>
          <Select
            style={_style}
            placeholder='请选择认证状态'
            value={auditStatus}
            onChange={this.onSelectChange('auditStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              commonAuditStatus && commonAuditStatus.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
