/**
 * 
 * 技能订单列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './SkillOrderFilters.less'
import { Select, Input, Button, DatePicker } from 'antd'
import moment from 'moment'
import { orderPayStatus, orderStatusArray } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class SkillOrderFilters extends Component {
  onInputChange = name => e => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange(name, value)
  }
  // 改变
  onSelectChange = name => key => {
    const { onChange } = this.props
    onChange && onChange(name, key)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { orderStatus, onSearch, skillName, payStatus, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']} hidden>
          <h4 className={styles['filter-label']}>技能名称:</h4>
          <Input 
            placeholder='请输入技能名称'
            style={_style}
            value={skillName}
            onChange={this.onInputChange('skillName')}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>支付状态:</h4>
          <Select
            style={_style}
            placeholder='请选择支付状态'
            value={payStatus}
            onChange={this.onSelectChange('payStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              orderPayStatus && orderPayStatus.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>订单状态:</h4>
          <Select
            style={_style}
            placeholder='请选择订单状态'
            value={orderStatus}
            onChange={this.onSelectChange('orderStatus')}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              orderStatusArray && orderStatusArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default SkillOrderFilters
