/**
 * 
 * 语音速配 筛选条件
 */
import React, { Component } from 'react'
import styles from './VoiceChatListFilters.less'
import { Select, Input, Button, DatePicker } from 'antd'
import moment from 'moment'
import { voiceChatStatus } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onInput = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('targetUserName', value)
  }
  onUserName = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('userName', value)
  }
  // 状态改变
  onStatusChange = key => {
    const { onChange } = this.props
    onChange && onChange('handleStatus', key)
  }
  // 是否机器人
  onRobotChange = key => {
    const { onChange } = this.props
    onChange && onChange('isRobot', key)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date').valueOf()
      _endTime = moments[1].endOf('date').valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render() {
    const { onSearch, handleStatus, userName, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']} hidden>
          <h4 className={styles['filter-label']}>用户名称:</h4>
          <Input
            placeholder='请输入用户名称'
            style={_style}
            value={userName}
            onChange={this.onUserName}
            allowClear
          />
        </div>

        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>状态:</h4>
          <Select
            style={_style}
            placeholder='请选择状态'
            value={handleStatus}
            onChange={this.onStatusChange}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              voiceChatStatus && voiceChatStatus.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>时间:</h4>
          <RangePicker
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div className={styles['search-btn']}>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
