import React, { Fragment } from 'react'
import { Table, Button, Card, Input, notification, Select, Popconfirm, Tag, Radio, message, Icon, Row, Drawer, Empty, Col, Typography, Pagination, Form, Badge } from 'antd'
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getAgentBankcardPageList, createAgentBankcard, deleteAgentBankcard, enableAgentBankcard, disableAgentBankcard, editAgentBankcard } from './services/api'
import * as Format from '@/utils/Format'
import styles from './AccountList.less'
import { objFilter } from '@/utils/Help';
import { connect } from 'dva';

import router from 'umi/router'

const { Paragraph } = Typography;
const Option = Select.Option
const FormItem = Form.Item
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24
    },
    sm: {
      span: 7
    },
  },
  wrapperCol: {
    xs: {
      span: 24
    },
    sm: {
      span: 12
    },
    md: {
      span: 10
    },
  },
};

@connect(state => {
  return { currentUser: state.user.currentUser }
})
@Form.create()
class AccountList extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      list: [],
      loading: false,
      pageIndex: 1,
      pagination: {
        current: 1,
        total: 0,
        pageSize: 15
      },
      info: {},
      balance: 0
    }
  }

  componentDidMount() {
    this.getAgentBankcardPageList(this.state.pagination.current);
  }


  //获取账户列表
  getAgentBankcardPageList(pageIndex) {
    const { pagination, loading, cardNo, cardStatus } = this.state;
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const params = {
        cardStatus, //商品状态
        cardNo, //商品名称
        pageIndex: pageIndex ? pageIndex : pagination.current,
        pageSize: pagination.pageSize,
        familyId: this.props.currentUser.familyId
      };
      objFilter(params); //去除空字段
      const res = await getAgentBankcardPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageIndex;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
      } else {
        this.setState({ loading: false });
      }
    });
  }

  //添加账户
  createAgentBankcard() {
    const { type, info } = this.state
    const { currentUser } = this.props
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (err) return
      let addLoading = true
      this.setState({ addLoading }, async () => {
        values.familyId = currentUser.familyId
        if (type === 'update') {
          values.cardId = info.cardId
        }
        console.log('添加账户：', values)
        const res = type === 'add' ? await createAgentBankcard(values) : await editAgentBankcard(values)
        if (res.msg === 'err') return
        addLoading = false
        if (res.code === 'OK') {
          notification['success']({
            message: type === 'add' ? '提现账户添加成功' : '提现账户编辑成功'
          })
          this.setState({ addLoading, addModal: false }, () => {
            this.getAgentBankcardPageList()
            this.props.form.resetFields()
          })
        } else {
          this.setState({ addLoading })
        }
      })
    })
  }

  handleVisible(name, visible) {
    const state = this.state
    state[name] = visible
    this.setState(state)
  }

  onAdd() {
    this.props.form.resetFields()
    this.setState({ addModal: true, type: 'add', info: {} })
  }

  //删除
  deleteAgentBankcard(info, i) {
    if (this.state.delLoading) return
    this.setState({ delLoading: true }, async () => {
      const res = await deleteAgentBankcard({ cardId: info.cardId })
      if (res.code === "OK") {
        notification['success']({
          message: '账户删除成功'
        })
        const { list } = this.state
        list.splice(i, 1)
        this.setState({ list, delLoading: false })
      } else {
        this.setState({ delLoading: false })
      }
    })
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    const { getFieldDecorator } = this.props.form;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline">
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">
            <Col md={8} sm={24}>
              <FormItem label="账号">
                <Input placeholder="账号" allowClear value={this.state.cardNo} onChange={e => this.setState({ cardNo: e.target.value })} />
              </FormItem>
            </Col>
            <Col md={8} sm={24}>
              <FormItem label="状态">
                <Select allowClear placeholder="请选择状态" allowClear value={this.state.cardStatus} onChange={cardStatus => this.setState({ cardStatus })}>
                  <Option key={1} value={1}>启用</Option>
                  <Option key={0} value={0}>禁用</Option>
                </Select>
              </FormItem>
            </Col>
          </Row>
          <div style={{ marginBottom: 20 }}>
            <Button
              type="primary"
              loading={loading}
              icon="search"
              onClick={this.getAgentBankcardPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon="sync" onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  //重置搜索
  resetSearch() {
    this.setState({ cardNo: undefined, cardStatus: undefined })
  }

  testLog = () => {
    console.log(this.props)
  }

  onUpdate(info) {
    this.props.form.setFieldsValue({
      cardType: info.cardType.toString(),
      isAliAccount: info.isAliAccount,
      cardStatus: info.cardStatus,
      cardNo: info.cardNo,
      cardPhone: info.cardPhone,
      cardName: info.cardName
    })
    this.setState({ cardId: info.cardId, addModal: true, type: 'update', info })
  }

  //禁用
  handleStatus(cardId, needStatus) {
    const { handleStatusLoading } = this.state;
    if (handleStatusLoading) return;
    this.setState({ handleStatusLoading: true }, async () => {
      const res = needStatus === 0 ? await disableAgentBankcard({ cardId }) : await enableAgentBankcard({ cardId });
      if (res.success) {
        notification.success({
          message: `账户${needStatus === 0 ? '禁用' : '启用'}成功`,
        });
        this.setState({ handleStatusLoading: false }, () => {
          this.getAgentBankcardPageList(this.state.pagination.current);
        });
      } else {
        this.setState({ handleStatusLoading: false });
      }
    });
  }

  selectType = (value) => {
    if (value === '1') {
      this.props.form.setFieldsValue({
        isAliAccount: 0
      })
    }
  }

  render() {
    const { loading, list, info } = this.state
    const { getFieldDecorator, getFieldValue } = this.props.form
    let cardIdCardName = '证件号'
    if (getFieldValue('cardType') === '1') {
      cardIdCardName = '营业执照号'
    }
    if (getFieldValue('cardType') === '2') {
      cardIdCardName = '身份证号'
    }
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog}>{this.props.route.name}</span>}

      >
        <Card title="提现账户列表" extra={<Button type="primary" onClick={this.onAdd.bind(this)}>添加提现账户</Button>}>
          {this.renderSearch()}
          {list.length === 0 ? (
            <div style={{ backgroundColor: '#fff', padding: 30 }}>
              <Empty description="暂无提现账户" />
            </div>
          ) : (
              <Fragment>
                <Row type="flex" style={{ flexWrap: 'wrap' }}>
                  {list.map((item, i) => {
                    return (
                      <Card
                        key={i} style={{ marginBottom: 20, marginRight: 20 }}
                        actions={[
                          <Popconfirm placement="top" title="确定删除该账户吗？" onConfirm={this.deleteAgentBankcard.bind(this, item, i)} okText="确定删除" cancelText="取消">
                            <Icon type="delete" /> 删除
                          </Popconfirm>,
                          <div onClick={this.onUpdate.bind(this, item)}><Icon type="edit" /> 编辑</div>,
                          <div>
                            {item.cardStatus === 1 && (
                              <Popconfirm
                                title="确定禁用吗？"
                                onConfirm={this.handleStatus.bind(this, item.cardId, 0)}
                              >
                                <a><Icon type="setting" />禁用</a>
                              </Popconfirm>
                            )}
                            {item.cardStatus === 0 && (
                              <Popconfirm
                                title="确定启用吗？"
                                onConfirm={this.handleStatus.bind(this, item.cardId, 1)}
                              >
                                <a><Icon type="setting" />启用</a>
                              </Popconfirm>
                            )}
                          </div>
                        ]}
                      >
                        <AccountDetail item={item} />
                      </Card>
                    )
                  })}
                </Row>
                <Pagination {...this.state.pagination} onChange={this.getAgentBankcardPageList.bind(this, this.state.pagination.current)} />
              </Fragment>
            )}
        </Card>
        {/*添加账户*/}
        <Drawer
          visible={!!this.state.addModal}
          onClose={this.handleVisible.bind(this, 'addModal', false)}
          title="添加提现账户"
          width={520}
        >
          <Form>
            <FormItem label="账户类型" {...formItemLayout}>
              {getFieldDecorator('cardType', {
                rules: [{ required: true, message: '请选择账户类型' }],
                initialValue: '1'
              })(
                <Select placeholder="请选择账户类型" onSelect={this.selectType}>
                  <Option key="1" value="1">对公账户</Option>
                  <Option key="2" value="2">对私账户</Option>
                </Select>
              )}
            </FormItem>
            <FormItem className="hidden" label="是否支付宝" {...formItemLayout}>
              {getFieldDecorator('isAliAccount', {
                rules: [{ required: true, message: '请选择是否支付宝' }],
                initialValue: 0
              })(
                <Radio.Group disabled={getFieldValue('cardType') === '1'}>
                  <Radio value={1}>是</Radio>
                  <Radio value={0} style={{ marginLeft: 20 }}>
                    否
                  </Radio>
                </Radio.Group>,
              )}
            </FormItem>
            <FormItem label="户名" {...formItemLayout}>
              {getFieldDecorator('cardName', {
                rules: [{ required: true, message: '请输入户名' }],
              })(
                <Input placeholder="请输入户名" style={{ width: '100%' }} />
              )}
            </FormItem>
            <FormItem label={getFieldValue('isAliAccount') === 1 ? '支付宝账号' : '账号'} {...formItemLayout}>
              {getFieldDecorator('cardNo', {
                rules: [{ required: true, message: getFieldValue('isAliAccount') === 1 ? '支付宝账号' : '账号' }],
              })(
                <Input placeholder={getFieldValue('isAliAccount') === 1 ? '支付宝账号' : '账号'} style={{ width: '100%' }} />
              )}
            </FormItem>
            <FormItem label="通知手机号" {...formItemLayout}>
              {getFieldDecorator('cardPhone', {
                rules: [{ required: true, message: '请输入通知手机号' }],
              })(
                <Input placeholder="请输入通知手机号" style={{ width: '100%' }} />
              )}
            </FormItem>
            {getFieldValue('isAliAccount') === 0 && (
              <Fragment>
                <FormItem label="开户行" {...formItemLayout}>
                  {getFieldDecorator('cardDepositBank', {
                    rules: [{ required: true, message: '请输入开户行' }],
                    initialValue: info.cardDepositBank
                  })(
                    <Input placeholder="请输入开户行" style={{ width: '100%' }} />
                  )}
                </FormItem>
                <FormItem label={cardIdCardName} {...formItemLayout}>
                  {getFieldDecorator('cardIdCard', {
                    rules: [{ required: true, message: `请输入${cardIdCardName}` }],
                    initialValue: info.cardIdCard
                  })(
                    <Input placeholder={`请输入${cardIdCardName}`} style={{ width: '100%' }} />
                  )}
                </FormItem>
              </Fragment>
            )}
            <FormItem
              label="状态"
              {...formItemLayout}
            >
              {getFieldDecorator('cardStatus', {
                rules: [{ required: true, message: '请选择状态' }],
              })(
                <Select allowClear placeholder="请选择状态" allowClear>
                  <Option key={1} value={1}>启用</Option>
                  <Option key={0} value={0}>禁用</Option>
                </Select>
              )}
            </FormItem>
          </Form>
          <div
            style={{
              position: 'absolute',
              bottom: 0,
              width: '100%',
              borderTop: '1px solid #e8e8e8',
              padding: '10px 16px',
              textAlign: 'right',
              left: 0,
              background: '#fff',
              borderRadius: '0 0 4px 4px',
            }}
          >
            <Button style={{ marginRight: 8 }} onClick={this.handleVisible.bind(this, 'addModal', false)}>
              取消
            </Button>
            <Button loading={!!this.state.addLoading} onClick={this.createAgentBankcard.bind(this)} type="primary">
              {this.state.type === 'add' ? '确定添加' : '确定编辑'}
            </Button>
          </div>
        </Drawer>
      </PageHeaderWrapper>
    )
  }
}



export default AccountList

function AccountDetail(props) {
  const { item } = props
  if (item.isAliAccount === 1) {
    return (
      <div style={{ height: 255 }}>
        <Paragraph>
          账户类型：{item.cardType === 1 ? <Tag color="blue">对公账户</Tag> : <Tag color="orange">私人账户</Tag>}
          <Icon type="alipay" style={{ color: '#1890ff' }} />
        </Paragraph>
        <Paragraph>状态：{item.cardStatus === 1 ? <Badge text="启用" status="success" /> : <Badge text="禁用" status="error" />}</Paragraph>
        <Paragraph copyable={{ text: item.cardNo }}>支付宝账号：{item.cardNo}</Paragraph>
        <Paragraph copyable={{ text: item.cardName }}>户名：{item.cardName}</Paragraph>
        <Paragraph copyable={{ text: item.cardPhone }}>通知手机：{item.cardPhone}</Paragraph>
        <Paragraph>创建时间：{Format.date(item.cardCreateTime, 'yyyy-MM-dd HH:mm')}</Paragraph>
      </div>
    )
  } else {
    return (
      <div style={{ height: 255 }}>
        <Paragraph>账户类型：{item.cardType === 1 ? <Tag color="blue">对公账户</Tag> : <Tag color="orange">私人账户</Tag>}</Paragraph>
        <Paragraph>状态：{item.cardStatus === 1 ? <Badge text="启用" status="success" /> : <Badge text="禁用" status="error" />}</Paragraph>
        <Paragraph>开户行：{item.cardDepositBank}</Paragraph>
        <Paragraph copyable={{ text: item.cardNo }}>账号：{item.cardNo}</Paragraph>
        <Paragraph copyable={{ text: item.cardName }}>户名：{item.cardName}</Paragraph>
        <Paragraph copyable={{ text: item.cardPhone }}>通知手机：{item.cardPhone}</Paragraph>
        <Paragraph copyable={{ text: item.cardIdCard }}>{item.cardType === 1 ? '营业执照号' : '身份证号'}：{item.cardIdCard}</Paragraph>
        <Paragraph>创建时间：{Format.date(item.cardCreateTime, 'yyyy-MM-dd HH:mm')}</Paragraph>
      </div>
    )
  }
}



