import React, { Component } from 'react';
import styles from './Accountdetails.less';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Card, Tabs, Table, Button, Tag, DatePicker, Form, Radio } from 'antd';
const { RangePicker } = DatePicker;
const FormItem = Form.Item;
import { getDate, MyDate } from '@/utils/base';
import moment from 'moment';
import { getSumByTypeAndTime, getWalletHis } from './services/api.js';
const Column = Table.Column;
@Form.create()
export default class Accountdetails extends Component {
  constructor(props) {
    super(props);
    const [beginTime, endTime] = MyDate.getTimeDistance('today');
    this.state = {
      //开始时间
      beginTime: beginTime.startOf('date').valueOf(),
      endTime: endTime.endOf('date').valueOf(),
      loading: false,
      totalMoney: null,
      lastId: null,
      list: [],
      isIncome: 1
    }
  }
  handleSubmit = e => {
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (!err) {
        this.setState({
          beginTime: values.time[0],
          endTime: values.time[1],
          isIncome: values.isIncome,
          list: [],
          lastId: null
        }, () => {
          this.getTotalmoney(values.isIncome);
          this.getAccountdetails(values.isIncome);
        })
      }
    });
  };
  componentDidMount() {
    const { beginTime, endTime } = this.state;
    this.props.form.setFieldsValue({
      time: [moment(beginTime), moment(endTime)],
      isIncome: 1
    });
    this.getTotalmoney();
    this.getAccountdetails();
  }
  //获取账户明细求和
  getTotalmoney = async () => {
    const { beginTime, endTime, isIncome } = this.state;
    let _params = {
      beginTime: moment(beginTime).format('x'),
      endTime: moment(endTime).format('x'),
      isIncome: isIncome
    }
    this.setState({ loading: true });
    try {
      let res = await getSumByTypeAndTime(_params);
      this.setState({ totalMoney: res.data == null ? 0 : res.data });
    } catch (error) {
      console.log(error);
    } finally {
      this.setState({ loading: false });
    }
  }
  //获取账户明细
  getAccountdetails = async () => {
    const { beginTime, endTime, isIncome, lastId, list } = this.state;
    let _paramsdetails = {
      beginTime: moment(beginTime).format('x'),
      endTime: moment(endTime).format('x'),
      isIncome: isIncome,
    };
    if (lastId) {
      _paramsdetails.lastId = lastId;
    }
    this.setState({ loading: true });
    try {
      let result = await getWalletHis(_paramsdetails);
      this.setState({
        lastId: result.data.lastId,
        list: list.concat(result.data.list)
      });
    } catch (error) {
      console.log(error);
    } finally { this.setState({ loading: false }) };
  }

  //加载更多
  onLoadMore = () => {
    this.getAccountdetails();
  }

  render() {
    const { getFieldDecorator } = this.props.form;
    const rangeConfig = {
      rules: [{ required: true, message: '请选择查询时间' }],
    };
    const typeConfig = {
      rules: [{ required: true, message: '请选择类型' }]
    }
    const { loading, totalMoney, lastId, list, isIncome } = this.state;
    const listLength = list ? list.length : 0
    return (
      <PageHeaderWrapper>
        <Card title='账户明细' style={{ marginBottom: 10 }}>
          <Form layout="inline" onSubmit={this.handleSubmit}>
            <Form.Item label="查询类型">
              {getFieldDecorator('isIncome', typeConfig)(
                <Radio.Group>
                  <Radio value={1}>收入</Radio>
                  <Radio value={0}>支出</Radio>
                </Radio.Group>,
              )}
            </Form.Item>
            <Form.Item label="日期">
              {getFieldDecorator('time', rangeConfig)(
                <RangePicker
                  allowClear={false}
                />
              )}
            </Form.Item>
            <Form.Item>
              <Button
                type="primary"
                loading={loading}
                icon="search"
                htmlType="submit"
              >
                查询
            </Button>
            </Form.Item>
          </Form>
          <div className={styles.total}>总计：<span>{totalMoney}粉钻</span></div>
          <Table
            loading={loading}
            dataSource={list}
            rowKey='hisId'
            bordered
            pagination={false}
          >
            <Column
              title='说明'
              key='hisRemarks'
              dataIndex='hisRemarks'
              width='50%'
              render={(text, { hisRemarks }) => (
                <div
                  dangerouslySetInnerHTML={{ __html: hisRemarks }}
                />
              )}
            />
            <Column
              title='粉钻'
              key='balanceValue'
              dataIndex='balanceValue'
              render={(text, { balanceValue }) => (
                <div>{balanceValue}</div>
              )}
            />
            <Column
              title='创建时间'
              key='createTime'
              dataIndex='createTime'
              render={(text, { createTime }) => (
                <div>{createTime ? getDate(+createTime) : '-'}</div>
              )}
            />
          </Table>
          {
            !!listLength &&
            <div className={styles['load-more-wrap']}>
              {
                lastId
                  ? <Button
                    onClick={this.onLoadMore}
                    type='primary'
                    ghost
                  >加载更多</Button>
                  : <p>没有更多了</p>
              }
            </div>
          }
        </Card>
      </PageHeaderWrapper>
    )
  }
}
