import React, { Fragment } from 'react';
import {
  Card,
  Table,
  DatePicker,
  Button,
  Row,
  Col,
  Select,
  Badge,
  Form,
  Typography,
  Tag,
  Icon, message
} from 'antd';
import * as Format from '@/utils/Format';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getAgentWithdrawHisPageList, getBalance } from './services/api';
import router from 'umi/router';
import styles from './WithdrawRecord.less';
import { objFilter } from '../../utils/Help';
import moment from 'moment';
import Ellipsis from '@/components/Ellipsis';
import WithDrawAction from './components/WithDrawAction';
const { Paragraph } = Typography;

const { Column } = Table;
const Option = Select.Option;
const FormItem = Form.Item;
const { RangePicker } = DatePicker;

@Form.create()
class WithdrawRecord extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
      balance: 0
    };
  }

  componentDidMount() {
    this.getBalance()
    this.getAgentWithdrawHisPageList(this.state.pagination.current);
  }

  //提现记录
  getAgentWithdrawHisPageList(pageIndex) {
    const { pagination, loading } = this.state;
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const { applyStatus, time } = this.props.form.getFieldsValue();
      const params = {
        applyStatus, //提现状态
        pageIndex: pageIndex ? pageIndex : pagination.current,
        pageSize: pagination.pageSize,
        startTime: time && time.length > 0 ? time[0].valueOf() : null,
        endTime: time && time.length > 0 ? time[1].valueOf() : null,
      };
      objFilter(params); //去除空字段
      const res = await getAgentWithdrawHisPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageIndex;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
        sessionStorage.getAgentWithdrawHisPageList = JSON.stringify(params);
      } else {
        this.setState({ loading: false });
      }
    });
  }

  //获取余额
  getBalance = async () => {
    if (this.state.getBalanceLoading) return
    this.setState({ getBalanceLoading: true }, async () => {
      const res = await getBalance()
      if (res.success) {
        const balance = res.data.balance
        const applyStatus = res.data.applyStatus    // 101待审核, 201, "审核未通过, 202, "审核通过
        this.setState({ balance, applyStatus, getBalanceLoading: false })
      } else {
        this.setState({ getBalanceLoading: false })
      }
    })
  }

  // 翻页
  handlePage(page) {
    const pageIndex = page.current;
    this.getAgentWithdrawHisPageList(pageIndex);
  }

  //选择主播状态
  onSelectStatus(applyStatus) {
    this.setState({ applyStatus });
  }

  //跳转
  linkTo(url) {
    router.push(url);
  }

  //重置搜索
  resetSearch() {
    this.props.form.resetFields();
    sessionStorage.removeItem('getAgentWithdrawHisPageList');
  }

  testLog() {
    console.log(this.state);
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    const { getFieldDecorator } = this.props.form;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline">
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">

            <Col md={8} sm={24}>
              <FormItem label="提现状态">
                {getFieldDecorator('applyStatus')(
                  <Select allowClear placeholder="请选择审核状态">
                    <Option key={101} value={101}>
                      <Badge status="processing" text="审核中" />
                    </Option>
                    <Option key={201} value={201}>
                      <Badge status="error" text="审核未通过" />
                    </Option>
                    <Option key={202} value={202}>
                      <Badge status="success" text="审核通过" />
                    </Option>
                  </Select>,
                )}
              </FormItem>
            </Col>
            <Col md={16} sm={24}>
              <FormItem label="提现申请时间">
                {getFieldDecorator('time')(
                  <RangePicker
                    showTime={{
                      defaultValue: [
                        moment('00:00:00', 'HH:mm:ss'),
                        moment('23:59:59', 'HH:mm:ss'),
                      ],
                    }}
                  />,
                )}
              </FormItem>
            </Col>
          </Row>
          <div style={{ marginBottom: 20 }}>
            <Button
              type="primary"
              loading={loading}
              icon="search"
              onClick={this.getAgentWithdrawHisPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon="sync" onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  handleVisible(name, visible) {
    const state = this.state
    state[name] = visible
    this.setState(state)
  }

  onWithdraw = () => {
    if (this.state.balance === 0) {
      message.error('余额不足', 1.5)
      return
    }
    if (this.state.applyStatus === 101) {
      message.info('尚有提现在审核中', 1.5)
      return
    }
    this.setState({ withdrawModal: true })
  }

  renderContent = () => {
    return (
      <div>
        <div>
          <span style={{ marginRight: 10 }}>账户余额：{this.state.balance}粉钻</span>
          {this.state.applyStatus === 101 && <Badge text="一笔审核中" status="processing"></Badge>}
          <Button style={{ margin: '0px 20px' }} icon="sync" loading={this.state.getBalanceLoading} onClick={this.getBalance}>刷新</Button>
          <Button type="primary" onClick={this.onWithdraw} icon="cloud-upload">申请提现</Button>
        </div>
      </div>
    )
  }

  afterApply = () => {
    this.getBalance()
    this.getAgentWithdrawHisPageList(this.state.pagination.current);
    this.setState({ withdrawModal: false })
  }

  render() {
    const { list } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>{this.props.route.name}</span>}
        content={this.renderContent()}
        onBack={() => router.goBack()}
      >
        <Card title="提现记录">
          {this.renderSearch()}
          <Table
            rowKey="hisId"
            loading={this.state.loading}
            pagination={this.state.pagination}
            onChange={this.handlePage.bind(this)}
            dataSource={list}
          >
            <Column
              title="提现数量"
              dataIndex="amount"
              key="amount"
              render={amount => amount == 0 || amount ? amount + '粉钻' : '--'}
            />
            <Column
              title="实际金额"
              dataIndex="actualAmount"
              key="actualAmount"
              render={actualAmount => actualAmount == 0 || actualAmount ? (actualAmount / 100) + '元' : '--'}
            />
            <Column
              title="税"
              dataIndex="taxAmount"
              key="taxAmount"
              render={taxAmount => taxAmount == 0 || taxAmount ? (taxAmount / 100) + '元' : '--'}
            />
            <Column
              title="提现状态"
              key="applyStatus"
              dataIndex="applyStatus"
              render={applyStatus => (
                <Fragment>
                  {applyStatus === 101 && <Badge status="processing" text="待审核" />}
                  {applyStatus === 201 && <Badge status="error" text="审核未通过" />}
                  {applyStatus === 202 && <Badge status="success" text="审核通过" />}
                </Fragment>
              )}
            />
            <Column
              title="申请时间"
              dataIndex="hisCreateTime"
              key="hisCreateTime"
              render={hisCreateTime => Format.date(hisCreateTime, 'yyyy-MM-dd HH:mm')}
            />
            <Column
              title="审核时间"
              dataIndex="hisApplyTime"
              key="hisApplyTime"
              render={hisApplyTime => Format.date(hisApplyTime, 'yyyy-MM-dd HH:mm')}
            />
            <Column
              title="审核备注"
              dataIndex="applyRemarks"
              key="applyRemarks"
              render={applyRemarks => <Ellipsis tooltip lines={3}>{applyRemarks || '--'}</Ellipsis>}
            />
            <Column
              title="提现账户"
              key="bankcard"
              dataIndex="bankcard"
              render={bankcard => (
                <Fragment>
                  <AccountDetail item={bankcard || {}} />
                </Fragment>
              )}
            />
          </Table>
        </Card>
        {/* 提现申请 */}
        <WithDrawAction
          drawerProps={{
            title: '提现申请',
            width: 600,
            visible: !!this.state.withdrawModal,
            onClose: () => this.setState({ withdrawModal: false })
          }}
          afterApply={this.afterApply}
          balance={this.state.balance}
        />
      </PageHeaderWrapper>
    );
  }
}

export default WithdrawRecord;

function AccountDetail(props) {
  const { item } = props
  if (item.isAliAccount === 1) {
    return (
      <div className={styles.bankcard}>
        <Paragraph>
          账户类型：{item.cardType === 1 ? <Tag color="blue">对公账户</Tag> : <Tag color="orange">私人账户</Tag>}
          <Icon type="alipay" style={{ color: '#1890ff' }} />
        </Paragraph>
        <Paragraph copyable={{ text: item.cardNo }}>支付宝账号：{item.cardNo}</Paragraph>
        <Paragraph copyable={{ text: item.cardName }}>户名：{item.cardName}</Paragraph>
        <Paragraph copyable={{ text: item.cardPhone }}>通知手机：{item.cardPhone}</Paragraph>
      </div>
    )
  } else {
    return (
      <div className={styles.bankcard}>
        <Paragraph>账户类型：{item.cardType === 1 ? <Tag color="blue">对公账户</Tag> : <Tag color="orange">私人账户</Tag>}</Paragraph>
        <Paragraph>开户行：{item.cardDepositBank}</Paragraph>
        <Paragraph copyable={{ text: item.cardNo }}>账号：{item.cardNo}</Paragraph>
        <Paragraph copyable={{ text: item.cardName }}>户名：{item.cardName}</Paragraph>
        <Paragraph copyable={{ text: item.cardPhone }}>通知手机：{item.cardPhone}</Paragraph>
        <Paragraph copyable={{ text: item.cardIdCard }}>{item.cardType === 1 ? '营业执照号' : '身份证号'}：{item.cardIdCard}</Paragraph>
      </div>
    )
  }
}
