// {/* 提现账户选择 */ }
// <AccountSelest
//   drawerProps={{
//     title: '提现账户选择',
//     width: 600,
//     visible: !!this.state.accountModal,
//     onClose: () => this.setState({ accountModal: false })
//   }}
//   onSelect={accountInfo => this.setState({ accountInfo, accountModal: false })}
// />


import React, { Fragment } from 'react';
import {
  Table,
  Button,
  Row,
  Col,
  Input,
  Form,
  Drawer,
  Select,
  List,
  Icon,
  Tag,
  Divider
} from 'antd';
import { getAgentBankcardPageList } from '../services/api';
import router from 'umi/router';
import styles from './AccountSelest.less';
import { objFilter } from '@/utils/Help';
import { connect } from 'dva';

const { Column } = Table;
const Option = Select.Option;
const FormItem = Form.Item;

@connect(state => {
  return { currentUser: state.user.currentUser }
})
//礼物选择器
@Form.create()
class AccountSelest extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
      giftName: '',
      giftInfo: {}
    };
  }

  componentDidMount() {
    this.getAgentBankcardPageList(1)
  }

  //获取账户列表
  getAgentBankcardPageList(pageIndex) {
    const { pagination, loading } = this.state;
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const { cardNo, cardType } = this.props.form.getFieldsValue();
      const params = {
        cardNo,
        cardType,
        pageIndex: pageIndex ? pageIndex : pagination.current,
        pageSize: pagination.pageSize,
        agentId: this.props.currentUser.agentId
      };
      objFilter(params); //去除空字段
      const res = await getAgentBankcardPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageIndex;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
      } else {
        this.setState({ loading: false });
      }
    });
  }

  // 翻页
  handlePage(page) {
    const pageNum = page.current;
    this.getAgentBankcardPageList(pageNum);
  }

  //输入搜索名称
  handleSearchName(e) {
    this.setState({ giftName: e.target.value });
  }

  //跳转
  linkTo(url) {
    router.push(url)
  }

  //重置搜索
  resetSearch() {
    this.props.form.resetFields();
  }

  testLog() {
    console.log(this.state);
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    const { getFieldDecorator } = this.props.form;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline">
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">
            <Col md={24} sm={24}>
              <FormItem label="账号">
                {getFieldDecorator('cardNo')(
                  <Input placeholder='账号' allowClear />
                )}
              </FormItem>
            </Col>
            <Col md={24} sm={24}>
              <FormItem label="类型">
                {getFieldDecorator('cardType')(
                  <Select allowClear placeholder="类型" allowClear>
                    <Option key="1" value="1">对公账户</Option>
                    <Option key="2" value="2">对私账户</Option>
                  </Select>
                )}
              </FormItem>
            </Col>
          </Row>
          <div style={{ marginBottom: 20 }}>
            <Button
              type="primary"
              loading={loading}
              icon="search"
              onClick={this.getAgentBankcardPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon="sync" onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  //选择
  onSelect(tagInfo) {
    if (this.props.onSelect) {
      this.props.onSelect(tagInfo)
    }
  }
  render() {
    const { list } = this.state;
    const { drawerProps } = this.props
    return (
      <Drawer {...drawerProps}>
        {this.renderSearch()}
        <List
          itemLayout="horizontal"
          dataSource={list}
          bordered
          pagination={this.state.pagination}
          renderItem={item => (
            <List.Item>
              <List.Item.Meta
                title={
                  <Row type="flex" justify="space-between">
                    <div>
                      {item.cardType === 1 ? <Tag color="blue">对公账户</Tag> : <Tag color="orange">私人账户</Tag>}
                      {item.isAliAccount === 1 && <Icon type="alipay" style={{ color: '#1890ff' }} />}
                    </div>
                    <Button type="primary" size="small" ghost onClick={() => this.props.onSelect(item)}>选择</Button>
                  </Row>
                }
                description={
                  <div className={styles.description}>
                    {item.isAliAccount === 1 && (
                      <div className={styles.content}>
                        <span>支付宝账号：{item.cardNo}</span>
                        <Divider type="vertical" />
                        <span>户名：{item.cardName}</span>
                        <Divider type="vertical" />
                        <span>通知手机：{item.cardPhone}</span>
                      </div>
                    )}
                    {item.isAliAccount !== 1 && (
                      <Fragment>
                        <div className={styles.content}>
                          <span>开户行：{item.cardDepositBank}</span>
                          <Divider type="vertical" />
                          <span>账号：{item.cardNo}</span>
                          <Divider type="vertical" />

                        </div>
                        <div>
                          <span>户名：{item.cardName}</span>
                          <Divider type="vertical" />
                          <span>通知手机：{item.cardPhone}</span>
                          <Divider type="vertical" />
                          <span>{item.cardType === 1 ? '营业执照号' : '身份证号'}：{item.cardIdCard}</span>
                        </div>
                      </Fragment>
                    )}
                  </div>
                }
              />
            </List.Item>
          )}
        />
      </Drawer>
    );
  }
}

export default AccountSelest;
