import React from 'react'
import { Drawer, Form, InputNumber, Button, Tag, message, notification } from 'antd'
import { applyWithdraw } from '../services/api'
import AccountSelest from './AccountSelest';
import RedStar from '@/components/Custom/RedStar';

const FormItem = Form.Item;
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 7,
    },
  },
  wrapperCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 12,
    },
    md: {
      span: 10,
    },
  },
};

@Form.create()
class WithDrawAction extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      accountInfo: {}
    }
  }

  handleSubmit() {
    const { form } = this.props;
    form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        this.applyWithdraw(values);
      }
    });
  }

  async applyWithdraw(values) {
    const { submitLoading, accountInfo } = this.state
    if (!accountInfo.cardId) {
      message.error('请选择提现账户', 1)
      return
    }
    const params = {
      ...values,
      cardId: accountInfo.cardId
    }
    console.log(`提交: `, params);
    if (submitLoading) return;
    this.setState({ submitLoading: true });
    const res = await applyWithdraw(params)
    if (res.msg === 'err') return;
    if (res.code === 'OK') {
      notification['success']({
        message: '提现申请成功'
      });
      this.setState({ submitLoading: false, accountInfo: {} }, () => {
        this.props.form.resetFields()
        this.props.afterApply()
      });
    } else {
      this.setState({ submitLoading: false });
    }
  }


  render() {
    const { drawerProps } = this.props
    const { getFieldDecorator } = this.props.form;
    const { accountInfo } = this.state
    return (
      <Drawer {...drawerProps}>
        <Form>
          <FormItem label="粉钻" {...formItemLayout}>
            {this.props.balance}
          </FormItem>
          <FormItem label="提现数量" {...formItemLayout}>
            {getFieldDecorator('amount', {
              rules: [{ required: true, message: '请输入提现数量' }],
            })(
              <InputNumber style={{ width: '100%' }} min={1} placeholder="请输入提现数量" />
            )}
          </FormItem>
          <FormItem label={<RedStar title="提现账户" />} {...formItemLayout}>
            {accountInfo.cardId ? (
              <Tag closable onClose={() => this.setState({ accountInfo: {} })}>{accountInfo.cardNo}</Tag>
            ) : (
                <Button onClick={() => this.setState({ accountModal: true })}>选择提现账户</Button>
              )}
          </FormItem>

          <div style={{ textAlign: 'center' }}>
            <Button
              type="primary"
              size="large"
              loading={!!this.state.submitLoading}
              onClick={this.handleSubmit.bind(this)}
            >
              确定提现
          </Button>
          </div>
        </Form>
        {/* 提现账户选择 */}
        <AccountSelest
          drawerProps={{
            title: '提现账户选择',
            width: 600,
            visible: !!this.state.accountModal,
            onClose: () => this.setState({ accountModal: false })
          }}
          onSelect={accountInfo => this.setState({ accountInfo, accountModal: false })}
        />
      </Drawer>
    )
  }
}

export default WithDrawAction


