import moment from 'moment'
// 补 0
function fixedZero(val) {
  return val * 1 < 10 ? `0${val}` : val;
}
// 获取本日、本周、本月、本年等
/**
 * @param {string|number} type 类型
 * @return {Array[moment, moment?]} 返回值
 */
function getTimeDistance(type) {
  // 今天的时间对象
  const now = new Date();
  // 今天的moment
  const nowMoment = moment()
  // 一天的时间 毫秒数
  const oneDay = 1000 * 60 * 60 * 24;
  // 如果是数值类型 向后推 type 天
  if (typeof type === 'number') {
    return [
      nowMoment.clone().subtract(type - 1, 'days').startOf('date'),
      nowMoment.clone().endOf('date')
    ]
  }

  // 本日
  if (type === 'today') {
    return [
      nowMoment.clone().startOf('date'),
      nowMoment.clone().endOf('date')
    ]
  }

  // 本周
  if (type === 'week') {
    return [
      nowMoment.clone().startOf('week'),
      nowMoment.clone().endOf('date')
    ]
  }

  // 本月
  if (type === 'month') {
    return [
      nowMoment.clone().startOf('month'),
      nowMoment.clone().endOf('date')
    ]
  }

  // 本年
  if (type === 'thisYear') {
    return [
      nowMoment.clone().startOf('year'),
      nowMoment.clone().endOf('date')
    ]
  }

  const year = now.getFullYear();
  // type year 统计的本年 时间选择器是年的时间选择器
  if (type === 'year') {
    return [moment(`${year}`)]
  }

  // 昨天
  if (type === 'yesterday') {
    // 减去时间
    const yesterdayMoment = moment().subtract(1, 'days')
    return [
      yesterdayMoment.clone().startOf('date'),
      yesterdayMoment.clone().endOf('date')
    ]
  }

  // 上周
  if (type === 'lastWeek') {
    // 本周的第一天
    const weekFirstDay = nowMoment.clone().startOf('week')
    const lastWeekFirstDay = weekFirstDay.clone().subtract(7, 'days')
    // 向后倒退 1秒
    const lastWeekLastDay = weekFirstDay.subtract(1, 's')
    return [
      lastWeekFirstDay,
      lastWeekLastDay
    ]
  }

  // 上月
  if (type === 'lastMonth') {
    // 本月的第一天
    const monthFirstDay = nowMoment.clone().startOf('month')
    const lastMonthFirstDay = monthFirstDay.clone().subtract(1, 'month')
    // 向后倒退 1秒
    const lastMonthLastDay = monthFirstDay.subtract(1, 's')
    return [
      lastMonthFirstDay,
      lastMonthLastDay
    ]
  }

  // 默认返回今天好了
  return [
    nowMoment.clone().startOf('date'),
    nowMoment.clone().endOf('date')
  ]
}

// 解析后台的时间 201907, 20190730
const getTimeFromLong = (time) => {
  if (!time) {
    return {}
  }
  let timeStr = time + ''
  let timeStrLen = timeStr.length
  let _result = {
    y: '', M: '', d: '', h: '', m: ''
  }
  // 年
  _result.y = timeStr.substr(0, 4)
  // 月
  if (timeStrLen === 6) {
    _result.M = timeStr.substr(4, 2)
  }
  // 日
  if (timeStrLen === 8) {
    _result.M = timeStr.substr(4, 2)
    _result.d = timeStr.substr(6, 2)
  }
  // 时
  if (timeStrLen === 10) {
    _result.M = timeStr.substr(4, 2)
    _result.d = timeStr.substr(6, 2)
    _result.h = timeStr.substr(8, 2)
  }
  // 分
  if (timeStrLen === 12) {
    _result.M = timeStr.substr(4, 2)
    _result.d = timeStr.substr(6, 2)
    _result.h = timeStr.substr(8, 2)
    _result.m = timeStr.substr(10, 2)
  }
  return _result
}

const getTime = (type, value) => {
  switch (type) {
    case 'minutes':
      //获取当前时间前几十分钟的时间段
      return [
        moment().subtract(value, 'minutes'),
        moment().subtract('minutes')
      ];
    case 'hours':
      //获取当前时间的前几个小时时间段
      return [
        moment().subtract(value, 'hours'),
        moment().subtract('hours')
      ];
    case 'days':
      //获取当前时间的前几天时间段
      return [
        moment().subtract(value, 'days'),
        moment().subtract('days')
      ];
    case 'weeks':
      //获取本周时间段
      return [
        moment().clone().startOf('week'),
        moment().clone().endOf('date')
      ];
    case 'months':
      //获取当前时间的前几天时间段
      return [
        moment().subtract(value, 'months'),
        moment().subtract('months')
      ];
    default:
      [
        moment().clone().startOf('date'),
        moment().clone().endOf('date')
      ];
  }
}
export default {
  getTimeDistance, getTimeFromLong, getTime
}
